@@ -1,18 +1,20 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_desktop_items_hpp__
-#define __INC_desktop_items_hpp__
+#pragma once
 
-#include "main_window.hpp"
-#include <QScopedPointer>
+#include <memory>
+
+// Forward declaration
+class Main_Window;
 
 /// @brief Manages all items that appear on the desktop
 ///
 class Desktop_Items
 {
-  // Public methods
   public:
+  // -- Construction
+
   Desktop_Items ();
 
   ~Desktop_Items ();
@@ -34,9 +36,7 @@ class Desktop_Items
   int
   parse_cmd_options ( int argc, char * argv[] );
 
-  // Private attributes
   private:
-  QScopedPointer< Main_Window > _mwin;
+  // -- Attributes
+  std::unique_ptr< Main_Window > _mwin;
 };
-
-#endif
