@@ -28,8 +28,8 @@ main ( int argc, char * argv[] )
   }
 
   // Load application icon, translators
-  ::Views::load_application_icon ( &app, "multimedia-volume-control" );
-  ::Views::load_translators ( &app );
+  Views::load_application_icon ( &app, "multimedia-volume-control" );
+  Views::load_translators ( &app );
 
   ditems.start ( app.isSessionRestored () );
 
