@@ -7,6 +7,7 @@
 #include "views/info_dialog.hpp"
 #include "views/view_utility.hpp"
 #include <QAction>
+#include <QApplication>
 #include <QMenu>
 #include <QMenuBar>
 #include <QSettings>
@@ -19,13 +20,58 @@ Main_Window::Main_Window ()
   setObjectName ( PROGRAM_TITLE );
   setContextMenuPolicy ( Qt::NoContextMenu );
 
-  init_menu_bar ();
+  {
+    // Action: Quit
+    QAction * act_quit ( new QAction ( tr ( "&Quit" ), this ) );
+    act_quit->setShortcut ( QKeySequence ( QKeySequence::Quit ) );
+    act_quit->setIcon ( QIcon::fromTheme ( "application-exit" ) );
+
+    // Action: Refresh
+    QAction * act_refresh ( new QAction ( tr ( "&Refresh" ), this ) );
+    act_refresh->setShortcut ( QKeySequence ( QKeySequence::Refresh ) );
+    act_refresh->setIcon ( QIcon::fromTheme ( "view-refresh" ) );
+
+    // Action: About
+    QAction * act_about = Views::Info_Dialog::create_action_about ( this );
+    QAction * act_about_qt =
+        Views::Info_Dialog::create_action_about_qt ( this );
+
+    // Menu: File
+    {
+      QMenu * cmenu ( menuBar ()->addMenu ( tr ( "&File" ) ) );
+      cmenu->addAction ( act_quit );
+    }
+
+    // Menu: View
+    {
+      QMenu * cmenu = menuBar ()->addMenu ( tr ( "&View" ) );
+      cmenu->addAction ( act_refresh );
+    }
+
+    // Menu: Help
+    {
+      QMenu * cmenu = menuBar ()->addMenu ( tr ( "&Help" ) );
+      cmenu->addAction ( act_about );
+      cmenu->addAction ( act_about_qt );
+    }
+
+    // Connect actions
+    connect ( act_quit, &QAction::triggered, this, &Main_Window::close );
+    connect ( act_refresh, &QAction::triggered, this, &Main_Window::refresh );
+    connect (
+        act_about, &QAction::triggered, this, &Main_Window::show_dialog_about );
+    connect ( act_about_qt,
+              &QAction::triggered,
+              this,
+              &Main_Window::show_dialog_about_qt );
+  }
 
   {
-    ::QSnd::ALSA_Config_Watcher * watcher (
-        new ::QSnd::ALSA_Config_Watcher ( this ) );
-
-    connect ( watcher, SIGNAL ( sig_change () ), this, SLOT ( refresh () ) );
+    auto * watcher = new QSnd::ALSA_Config_Watcher ( this );
+    connect ( watcher,
+              &QSnd::ALSA_Config_Watcher::sig_change,
+              this,
+              &Main_Window::refresh );
   }
 
   _alsa_cfg_view.set_model ( &_alsa_cfg_model );
@@ -33,11 +79,13 @@ Main_Window::Main_Window ()
   setCentralWidget ( &_alsa_cfg_view );
 }
 
+Main_Window::~Main_Window () = default;
+
 QSize
 Main_Window::sizeHint () const
 {
   QSize res ( QMainWindow::sizeHint () );
-  ::Views::win_default_size ( res );
+  Views::win_default_size ( this, res );
   return res;
 }
 
@@ -70,7 +118,7 @@ Main_Window::restore_state ()
   // Apply settings
   restoreState ( mwin_state );
   if ( !restoreGeometry ( mwin_geom ) ) {
-    ::Views::resize_to_default ( this );
+    Views::resize_to_default ( this );
   }
   _alsa_cfg_view.set_sorting_enabled ( cfg_sorted );
 }
@@ -91,68 +139,26 @@ Main_Window::save_state ()
 }
 
 void
-Main_Window::show_info_dialog ()
+Main_Window::show_dialog_about ()
 {
-  if ( _info_dialog == 0 ) {
-    ::Views::Info_Dialog * dlg ( new ::Views::Info_Dialog ( this ) );
+  if ( _info_dialog == nullptr ) {
+    Views::Info_Dialog * dlg = new Views::Info_Dialog ( this );
     dlg->setAttribute ( Qt::WA_DeleteOnClose );
-
     _info_dialog = dlg;
   }
-
   _info_dialog->show ();
 }
 
 void
-Main_Window::init_menu_bar ()
+Main_Window::show_dialog_about_qt ()
 {
-  // Action: Quit
-  QAction * act_quit ( new QAction ( tr ( "&Quit" ), this ) );
-  act_quit->setShortcut ( QKeySequence ( QKeySequence::Quit ) );
-  act_quit->setIcon ( QIcon::fromTheme ( "application-exit" ) );
-
-  // Action: Refresh
-  QAction * act_refresh ( new QAction ( tr ( "&Refresh" ), this ) );
-  act_refresh->setShortcut ( QKeySequence ( QKeySequence::Refresh ) );
-  act_refresh->setIcon ( QIcon::fromTheme ( "view-refresh" ) );
-
-  // Action: Info
-  QAction * act_info = new QAction ( tr ( "&Info" ), this );
-  act_info->setShortcut ( QKeySequence ( QKeySequence::HelpContents ) );
-  act_info->setIcon ( QIcon::fromTheme ( "help-about" ) );
-
-  // Menu: File
-  {
-    QMenu * cmenu ( menuBar ()->addMenu ( tr ( "&File" ) ) );
-    cmenu->addAction ( act_quit );
-  }
-
-  // Menu: View
-  {
-    QMenu * cmenu = menuBar ()->addMenu ( tr ( "&View" ) );
-    cmenu->addAction ( act_refresh );
-  }
-
-  // Menu: Help
-  {
-    QMenu * cmenu = menuBar ()->addMenu ( tr ( "&Help" ) );
-    cmenu->addAction ( act_info );
-  }
-
-  // Connect actions
-
-  connect ( act_quit, SIGNAL ( triggered () ), this, SLOT ( close () ) );
-
-  connect ( act_refresh, SIGNAL ( triggered () ), this, SLOT ( refresh () ) );
-
-  connect (
-      act_info, SIGNAL ( triggered () ), this, SLOT ( show_info_dialog () ) );
+  QApplication::aboutQt ();
 }
 
 void
 Main_Window::refresh ()
 {
-  //::std::cout << "Refresh" << "\n";
+  // std::cout << "Refresh" << "\n";
   _alsa_cfg_view.reload_config ();
 }
 
