@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_main_window_hpp__
-#define __INC_main_window_hpp__
+#pragma once
 
 #include "qsnd/alsa_config_model.hpp"
 #include "views/alsa_config_view.hpp"
@@ -16,12 +15,19 @@ class Main_Window : public QMainWindow
 {
   Q_OBJECT
 
-  // Public methods
   public:
+  // -- Construction
+
   Main_Window ();
 
+  ~Main_Window ();
+
+  // -- Size hint
+
   QSize
-  sizeHint () const;
+  sizeHint () const override;
+
+  // -- State store and restore
 
   void
   restore_state ();
@@ -29,34 +35,38 @@ class Main_Window : public QMainWindow
   void
   save_state ();
 
-  // Public slots
-  private slots:
+  // -- Public slots
 
+  Q_SLOT
   void
   refresh ();
 
-  // Protected methods
   protected:
-  void
-  closeEvent ( QCloseEvent * event_n );
-
-  // Private slots
-  private slots:
+  // -- Protected methods
 
   void
-  show_info_dialog ();
+  closeEvent ( QCloseEvent * event_n ) override;
 
-  // Private methods
   private:
+  // -- Private slots
+
+  Q_SLOT
+  void
+  show_dialog_about ();
+
+  Q_SLOT
+  void
+  show_dialog_about_qt ();
+
+  // -- Private methods
+
   void
   init_menu_bar ();
 
-  // Private attributes
   private:
-  ::QSnd::Alsa_Config_Model _alsa_cfg_model;
-  ::Views::Alsa_Config_View _alsa_cfg_view;
+  // Attributes
+  QSnd::Alsa_Config_Model _alsa_cfg_model;
+  Views::Alsa_Config_View _alsa_cfg_view;
 
   QPointer< QDialog > _info_dialog;
 };
-
-#endif
