@@ -3,79 +3,75 @@
 
 #include "static_tree.hpp"
 
-Static_Tree_Node::Static_Tree_Node ()
-: parent_idx ( 0 )
-, self_idx ( 0 )
-, children_idx ( 0 )
-{
-}
-
 Static_Tree::Static_Tree ()
 {
   reset ();
 }
 
+Static_Tree::~Static_Tree () = default;
+
 void
 Static_Tree::reset ()
 {
   clear ();
 
+  // Add root node
   Node nn_root;
   nn_root.parent_idx = 0;
   nn_root.self_idx = 0;
   nn_root.children_idx = 0;
-  append ( nn_root );
+  push_back ( nn_root );
 }
 
 const Static_Tree::Node *
 Static_Tree::parent_node ( const Node * node_n ) const
 {
-  if ( node_n != 0 ) {
+  if ( node_n != nullptr ) {
     if ( !is_root ( node_n ) ) {
       return node ( node_n->parent_idx );
     }
   }
-  return 0;
+  return nullptr;
 }
 
 Static_Tree::Node *
 Static_Tree::parent_node ( const Node * node_n )
 {
-  if ( node_n != 0 ) {
+  if ( node_n != nullptr ) {
     if ( !is_root ( node_n ) ) {
       return node ( node_n->parent_idx );
     }
   }
-  return 0;
+  return nullptr;
 }
 
 const Static_Tree::Node *
-Static_Tree::child_node ( const Node * node_n, Index_Type child_n ) const
+Static_Tree::child_node ( const Node * node_n, std::size_t child_n ) const
 {
-  if ( node_n != 0 ) {
+  if ( node_n != nullptr ) {
     if ( node_n->children_idx > 0 ) {
       return node ( node_n->children_idx + child_n );
     }
   }
-  return 0;
+  return nullptr;
 }
 
 Static_Tree::Node *
-Static_Tree::child_node ( const Node * node_n, Index_Type child_n )
+Static_Tree::child_node ( const Node * node_n, std::size_t child_n )
 {
-  if ( node_n != 0 ) {
+  if ( node_n != nullptr ) {
     if ( node_n->children_idx > 0 ) {
       return node ( node_n->children_idx + child_n );
     }
   }
-  return 0;
+  return nullptr;
 }
 
-Static_Tree::Index_Type
+std::size_t
 Static_Tree::depth ( const Node * node_n ) const
 {
-  Index_Type res ( 0 );
-  if ( node_n != 0 ) {
+  std::size_t res = 0;
+  if ( node_n != nullptr ) {
     while ( !is_root ( node_n ) ) {
       node_n = parent_node ( node_n );
       ++res;
@@ -84,14 +80,14 @@ Static_Tree::depth ( const Node * node_n ) const
   return res;
 }
 
-Static_Tree::Index_Type
+std::size_t
 Static_Tree::row ( const Node * node_n ) const
 {
-  Index_Type idx ( 0 );
-  if ( node_n != 0 ) {
+  std::size_t idx = 0;
+  if ( node_n != nullptr ) {
     idx = node_n->self_idx;
     while ( idx > 0 ) {
-      const Node * nn ( node ( idx ) );
+      const Node * nn = node ( idx );
       if ( nn->parent_idx != node_n->parent_idx ) {
         break;
       }
@@ -102,14 +98,14 @@ Static_Tree::row ( const Node * node_n ) const
   return idx;
 }
 
-Static_Tree::Index_Type
+std::size_t
 Static_Tree::num_children ( const Node * node_n ) const
 {
-  Index_Type res ( 0 );
-  if ( node_n != 0 ) {
+  std::size_t res = 0;
+  if ( node_n != nullptr ) {
     if ( node_n->children_idx > 0 ) {
-      const Index_Type idx_lim ( size () );
-      Index_Type idx ( node_n->children_idx );
+      const std::size_t idx_lim = size ();
+      std::size_t idx = node_n->children_idx;
       while ( idx < idx_lim ) {
         const Node * node_c = node ( idx );
         if ( node_c->parent_idx != node_n->self_idx ) {
@@ -125,29 +121,41 @@ Static_Tree::num_children ( const Node * node_n ) const
 
 void
 Static_Tree::rootline ( const Node * node_n,
-                        QList< unsigned int > & rows_n ) const
+                        std::vector< std::size_t > & rows_n ) const
 {
   rows_n.clear ();
-  if ( node_n != 0 ) {
+  if ( node_n != nullptr ) {
     while ( !is_root ( node_n ) ) {
-      rows_n.append ( row ( node_n ) );
+      rows_n.push_back ( row ( node_n ) );
       node_n = parent_node ( node_n );
     }
   }
 }
 
-void
-Static_Tree::append_children ( Node * node_n, Index_Type num_n )
+std::array< std::size_t, 2 >
+Static_Tree::append_children ( std::size_t node_idx_n, std::size_t num_n )
 {
-  if ( ( node_n == 0 ) || ( num_n <= 0 ) ) {
-    return;
+  std::array< std::size_t, 2 > child_range = { { 0, 0 } };
+  if ( ( node_idx_n >= size () ) || ( num_n == 0 ) ) {
+    return child_range;
   }
 
-  node_n->children_idx = size ();
-  for ( Index_Type ii = 0; ii < num_n; ++ii ) {
-    Node nn;
-    nn.parent_idx = node_n->self_idx;
-    nn.self_idx = size ();
-    append ( nn );
+  // Reserve space in advance. This invalidates all node pointers
+  const std::size_t size_new = size () + num_n;
+  if ( capacity () < size_new ) {
+    reserve ( size_new );
   }
+
+  child_range[ 0 ] = size ();
+  child_range[ 1 ] = size () + num_n;
+
+  node ( node_idx_n )->children_idx = child_range[ 0 ];
+  for ( std::size_t ii = 0; ii < num_n; ++ii ) {
+    Node nn;
+    nn.parent_idx = node_idx_n;
+    nn.self_idx = size ();
+    push_back ( nn );
+  }
+
+  return child_range;
 }
