@@ -3,35 +3,25 @@
 
 #include "static_tree_model.hpp"
 
-Static_Tree_Model::Static_Tree_Model ()
-: _num_columns ( 2 )
-{
-}
+Static_Tree_Model::Static_Tree_Model () = default;
 
-Static_Tree_Model::~Static_Tree_Model () {}
-
-void
-Static_Tree_Model::set_num_columns ( int num_n )
-{
-  _num_columns = num_n;
-}
+Static_Tree_Model::~Static_Tree_Model () = default;
 
 const Static_Tree_Model::Node *
 Static_Tree_Model::get_node ( const QModelIndex & index_n ) const
 {
-  int idx ( 0 );
   if ( index_n.isValid () ) {
-    idx = index_n.internalId ();
+    return stree ().node ( index_n.internalId () );
   }
-  return stree ().node ( idx );
+  return stree ().root_node ();
 }
 
 QModelIndex
 Static_Tree_Model::index ( const Node * node_n ) const
 {
-  if ( node_n != 0 ) {
-    const Node_Index node_row ( stree ().row ( node_n ) );
-    return createIndex ( node_row, 0, quint32 ( node_n->self_idx ) );
+  if ( node_n != nullptr ) {
+    const std::size_t node_row = stree ().row ( node_n );
+    return createIndex ( node_row, 0, node_n->self_idx );
   }
   return QModelIndex ();
 }
@@ -45,9 +35,9 @@ Static_Tree_Model::index ( int row,
     return QModelIndex ();
   }
 
-  const Node * node_p ( get_node ( parent_n ) );
-  if ( node_p != 0 ) {
-    if ( Node_Index ( row ) < stree ().num_children ( node_p ) ) {
+  const Node * node_p = get_node ( parent_n );
+  if ( node_p != nullptr ) {
+    if ( std::size_t ( row ) < stree ().num_children ( node_p ) ) {
       quint32 idx = node_p->children_idx + row;
       return createIndex ( row, column, idx );
     }
