@@ -16,7 +16,6 @@ namespace Views
 
 Alsa_Config_View::Alsa_Config_View ( QWidget * parent_n )
 : QWidget ( parent_n )
-, _alsa_cfg ( 0 )
 {
   QLabel * title_label ( new QLabel );
   {
@@ -46,7 +45,7 @@ Alsa_Config_View::Alsa_Config_View ( QWidget * parent_n )
             this,
             SLOT ( set_sorting_enabled ( bool ) ) );
 
-  _tree_view = new ::Wdg::Tree_View_KV ( this );
+  _tree_view = new Wdg::Tree_View_KV ( this );
   _sort_model = new QSortFilterProxyModel ( this );
 
   _tree_view->setSelectionMode ( QAbstractItemView::ExtendedSelection );
@@ -80,7 +79,7 @@ Alsa_Config_View::Alsa_Config_View ( QWidget * parent_n )
 Alsa_Config_View::~Alsa_Config_View () {}
 
 void
-Alsa_Config_View::set_model ( ::QSnd::Alsa_Config_Model * model_n )
+Alsa_Config_View::set_model ( QSnd::Alsa_Config_Model * model_n )
 {
   _alsa_cfg = model_n;
   _sort_model->setSourceModel ( _alsa_cfg );
@@ -198,7 +197,7 @@ void
 Alsa_Config_View::update_button_state ()
 {
   bool is_enabled ( false );
-  if ( _tree_view->selectionModel () != 0 ) {
+  if ( _tree_view->selectionModel () != nullptr ) {
     is_enabled = _tree_view->selectionModel ()->hasSelection ();
   }
 
