@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_views_alsa_config_view_hpp__
-#define __INC_views_alsa_config_view_hpp__
+#pragma once
 
 #include <QCheckBox>
 #include <QModelIndex>
@@ -30,48 +29,59 @@ class Alsa_Config_View : public QWidget
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  Alsa_Config_View ( QWidget * parent_n = 0 );
+  // -- Construction
+
+  Alsa_Config_View ( QWidget * parent_n = nullptr );
 
   ~Alsa_Config_View ();
 
-  ::QSnd::Alsa_Config_Model *
-  model () const;
+  // -- Model
+
+  QSnd::Alsa_Config_Model *
+  model () const
+  {
+    return _alsa_cfg;
+  }
 
   void
-  set_model ( ::QSnd::Alsa_Config_Model * model_n );
+  set_model ( QSnd::Alsa_Config_Model * model_n );
 
   bool
   sorting_enabled () const;
 
   // Public slots
-  public slots:
-
+  public:
+  Q_SLOT
   void
   reload_config ();
 
+  Q_SLOT
   void
   expand_to_level ( bool expanded_n );
 
+  Q_SLOT
   void
   expand_to_level ();
 
+  Q_SLOT
   void
   collapse_to_level ();
 
+  Q_SLOT
   void
   set_sorting_enabled ( bool flag_n );
 
   // Protected slots
-  protected slots:
-
+  protected:
+  Q_SLOT
   void
   items_selected ( const QItemSelection & sel0_n,
                    const QItemSelection & sel1_n );
 
-  // Protected methods
   protected:
+  // -- Protected methods
+
   void
   collect_expanded ( QStringList & lst_n,
                      const QModelIndex & = QModelIndex () );
@@ -82,13 +92,13 @@ class Alsa_Config_View : public QWidget
   void
   update_button_state ();
 
-  // Private attributes
   private:
-  ::QSnd::Alsa_Config_Model * _alsa_cfg;
+  // -- Attributes
+  QSnd::Alsa_Config_Model * _alsa_cfg = nullptr;
   QSortFilterProxyModel * _sort_model;
 
   // Widgets
-  ::Wdg::Tree_View_KV * _tree_view;
+  Wdg::Tree_View_KV * _tree_view;
   QPushButton _btn_expand;
   QPushButton _btn_collapse;
   QCheckBox _btn_sort;
@@ -97,12 +107,4 @@ class Alsa_Config_View : public QWidget
   QStringList _expanded_items;
 };
 
-inline ::QSnd::Alsa_Config_Model *
-Alsa_Config_View::model () const
-{
-  return _alsa_cfg;
-}
-
 } // namespace Views
-
-#endif
