@@ -1,19 +1,20 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_main_window_hpp__
-#define __INC_main_window_hpp__
+#pragma once
 
 #include "dpe/image_allocator.hpp"
 #include "main_window_setup.hpp"
+#include "mwdg/mixer_style_db.hpp"
+#include "qsnd/cards_db.hpp"
+#include "qsnd/ctl_address.hpp"
 #include "views/mixer_hctl.hpp"
-#include "wdg/ds_widget_style_db.hpp"
 #include <QDialog>
 #include <QFileSystemWatcher>
 #include <QMainWindow>
 #include <QPointer>
-#include <QScopedPointer>
 #include <QSplitter>
+#include <memory>
 
 // Forward declaration
 namespace Views
@@ -31,12 +32,20 @@ class Main_Window : public QMainWindow
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  Main_Window ();
+  // -- Construction
+
+  Main_Window ( QWidget * parent_n = nullptr,
+                Qt::WindowFlags flags_n = Qt::WindowFlags () );
+
+  ~Main_Window ();
+
+  // -- Size hints
 
   QSize
-  sizeHint () const;
+  sizeHint () const override;
+
+  // -- State store and restore
 
   void
   restore_state ();
@@ -44,67 +53,77 @@ class Main_Window : public QMainWindow
   void
   save_state ();
 
-  // Public slots
-  public slots:
+  // -- Public slots
 
+  Q_SLOT
   void
-  select_snd_ctl ( const QString & ctl_n );
+  select_snd_ctl ( const QSnd::Ctl_Address & ctl_n );
 
+  Q_SLOT
+  void
+  reload_mixer_device ();
+
+  Q_SLOT
   void
   refresh ();
 
+  Q_SLOT
   void
   set_fullscreen ( bool flag_n );
 
   // Device selection
 
+  Q_SLOT
   void
   show_device_selection ( bool flag_n );
 
+  Q_SLOT
   void
   toggle_device_selection ();
 
-  // Protected methods
   protected:
-  void
-  changeEvent ( QEvent * event_n );
+  // -- Protected methods
 
   void
-  closeEvent ( QCloseEvent * event_n );
+  changeEvent ( QEvent * event_n ) override;
 
-  // Private slots
-  private slots:
+  void
+  closeEvent ( QCloseEvent * event_n ) override;
 
+  private:
+  // -- Private slots
+
+  Q_SLOT
   void
   select_ctl_from_side_iface ();
 
+  Q_SLOT
   void
-  show_info_dialog ();
+  show_dialog_about ();
 
-  // Private methods
-  private:
+  Q_SLOT
   void
-  init_widgets ();
+  show_dialog_about_qt ();
 
-  void
-  init_menu_bar ();
+  // -- Private methods
 
   void
   update_fullscreen_action ();
 
-  // Private attributes
   private:
+  // -- Attributes
   // Shared storages and settings
-  ::Wdg::DS_Widget_Style_Db _wdg_style_db;
-  ::dpe::Image_Allocator _image_alloc;
+  MWdg::Mixer_Style_Db _mixer_style_db;
+  dpe::Image_Allocator _image_alloc;
+  QSnd::Cards_Db _cards_db;
 
   // Widgets settings
   Main_Window_Setup _setup;
 
   // Widgets
-  QScopedPointer< QSplitter > _splitter;
-  ::Views::Mixer_HCTL * _mixer_hctl;
-  ::Views::Device_Selection_View * _dev_select;
+  std::unique_ptr< QSplitter > _splitter;
+  Views::Mixer_HCTL * _mixer_hctl;
+  Views::Device_Selection_View * _dev_select;
 
   QPointer< QDialog > _info_dialog;
 
@@ -119,5 +138,3 @@ class Main_Window : public QMainWindow
   QIcon _icon_fscreen_enable;
   QIcon _icon_fscreen_disable;
 };
-
-#endif
