@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_main_window_setup_hpp__
-#define __INC_main_window_setup_hpp__
+#pragma once
 
 #include "mwdg/inputs_setup.hpp"
 #include "mwdg/mixer_device_setup.hpp"
@@ -15,19 +14,16 @@
 ///
 class Main_Window_Setup
 {
-  // Public methods
   public:
   Main_Window_Setup ();
 
-  // Public attributes
   public:
+  // -- Attributes
   bool show_dev_select;
 
-  ::MWdg::Mixer_Device_Setup mixer_dev;
-  ::MWdg::Inputs_Setup inputs;
+  MWdg::Mixer_Device_Setup mixer_dev;
+  MWdg::Inputs_Setup inputs;
 
-  ::Views::Mixer_HCTL_Setup hctl;
-  ::Views::Device_Selection_View_Setup dev_select;
+  Views::Mixer_HCTL_Setup hctl;
+  Views::Device_Selection_View_Setup dev_select;
 };
-
-#endif
