@@ -6,9 +6,8 @@
 namespace Views
 {
 
-Mixer_HCTL_Setup::Mixer_HCTL_Setup ()
-: elem_grp_index ( 9999 )
-{
-}
+Mixer_HCTL_Setup::Mixer_HCTL_Setup () = default;
+
+Mixer_HCTL_Setup::~Mixer_HCTL_Setup () = default;
 
 } // namespace Views
