@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_mv_mixer_hctl_setup_hpp__
-#define __INC_mv_mixer_hctl_setup_hpp__
+#pragma once
 
 #include "views/view_base_setup.hpp"
 #include <QString>
@@ -10,20 +9,23 @@
 namespace Views
 {
 
-class Mixer_HCTL_Setup : public ::Views::View_Base_Setup
+/// @brief Mixer_HCTL_Setup
+///
+class Mixer_HCTL_Setup : public Views::View_Base_Setup
 {
-  // Public methods
   public:
+  // -- Construction
+
   Mixer_HCTL_Setup ();
 
-  // Public attributes
+  ~Mixer_HCTL_Setup () override;
+
   public:
-  // Public attributes
+  // -- Attributes
+  QByteArray splitter_state;
   QString iface_name;
   QString elem_grp_name;
-  unsigned int elem_grp_index;
+  unsigned int elem_grp_index = 9999;
 };
 
 } // namespace Views
-
-#endif
