@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_cmd_options_hpp__
-#define __INC_cmd_options_hpp__
+#pragma once
 
 #include <QString>
 
@@ -12,15 +11,12 @@
 class CMD_Options
 {
 
-  // Public methods
   public:
   CMD_Options ();
 
-  // Public attributes
   public:
+  // -- Attributes
   bool start_tray_minimized;
   bool start_single_instance;
   QString start_ctl_address;
 };
-
-#endif
