@@ -5,54 +5,30 @@
 #include "info_texts.hpp"
 #include "main_window.hpp"
 #include "qastools_config.hpp"
-#include "tray_mixer.hpp"
+#include "tray/mixer.hpp"
 #include "views/info_dialog.hpp"
 #include "views/settings_dialog.hpp"
-#include "wdg/ds_slider_painter_bevelled.hpp"
-#include "wdg/ds_switch_painter_circle.hpp"
-#include "wdg/ds_switch_painter_close.hpp"
-#include "wdg/ds_switch_painter_svg.hpp"
-#include "wdg/ds_widget_types.hpp"
 #include <getopt.h>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QEvent>
 #include <QKeyEvent>
 #include <iostream>
+#include <memory>
 #include <sstream>
 
 Desktop_Items::Desktop_Items ( QObject * parent_n )
 : QObject ( parent_n )
-, _tray_mixer ( 0 )
-, _main_mixer ( 0 )
-, _started ( false )
-, _shutdown ( false )
+, _evt_mixer_closed ( QEvent::registerEventType () )
+, _cards_db ( this )
+, _mixer_states_db ( &_cards_db )
 {
-  // Init widget style database
-  {
-    ::MWdg::Mixer_Style mstyle;
-    ::MWdg::Mixer_Style::Style_Type stype;
-
-    stype = ::MWdg::Mixer_Style::PLAYBACK;
-    _wdg_style_db.palettes.insert ( stype, mstyle.style_palette ( stype ) );
-
-    stype = ::MWdg::Mixer_Style::CAPTURE;
-    _wdg_style_db.palettes.insert ( stype, mstyle.style_palette ( stype ) );
-  }
-
-  {
-    _dsetup.main_window.mixer_simple.wdg_style_db = &_wdg_style_db;
-    _dsetup.main_window.mixer_simple.image_alloc = &_image_alloc;
-  }
-  _dsetup.tray_view.image_alloc = &_image_alloc;
-
-  _evt_mixer_closed = QEvent::registerEventType ();
 }
 
 Desktop_Items::~Desktop_Items ()
 {
   if ( _started ) {
     shutdown ();
+    _mixer_states_db.write_to_storage ();
     _dsetup.write_to_storage ();
   }
 }
@@ -61,6 +37,7 @@ int
 Desktop_Items::init_settings ( int argc, char * argv[] )
 {
   _dsetup.read_from_storage ();
+  _mixer_states_db.read_from_storage ();
   return parse_cmd_options ( argc, argv );
 }
 
@@ -81,16 +58,17 @@ Desktop_Items::parse_cmd_options ( int argc, char * argv[] )
 
   while ( scan_further ) {
 
-    static struct option long_opts[] = {{"help", no_argument, 0, 'h'},
-                                        {"card", required_argument, 0, 'c'},
-                                        {"device", required_argument, 0, 'D'},
+    static struct option long_opts[] = {
+        { "help", no_argument, 0, 'h' },
+        { "card", required_argument, 0, 'c' },
+        { "device", required_argument, 0, 'D' },
 
-                                        {"tray", no_argument, 0, 't'},
-                                        {"no-single", no_argument, 0, 'n'},
+        { "tray", no_argument, 0, 't' },
+        { "no-single", no_argument, 0, 'n' },
 
-                                        {"copying", no_argument, 0, 'i'},
-                                        {"version", no_argument, 0, 'v'},
-                                        {0, 0, 0, 0}};
+        { "copying", no_argument, 0, 'i' },
+        { "version", no_argument, 0, 'v' },
+        { 0, 0, 0, 0 } };
 
     // getopt_long stores the option index here.
     int long_opts_idx ( 0 );
@@ -135,36 +113,36 @@ Desktop_Items::parse_cmd_options ( int argc, char * argv[] )
 
   if ( flag_print_help ) {
     {
-      ::std::stringstream msg;
-      msg << "Usage:" << ::std::endl;
-      msg << "  " << PROGRAM_NAME << " [OPTION]..." << ::std::endl;
-      msg << ::std::endl;
+      std::ostringstream msg;
+      msg << "Usage:" << std::endl;
+      msg << "  " << PROGRAM_NAME << " [OPTION]..." << std::endl;
+      msg << std::endl;
       msg << info_text_options;
-      msg << ::std::endl;
-      ::std::cout << msg.str () << ::std::flush;
+      msg << std::endl;
+      std::cout << msg.str () << std::flush;
     }
     return -1;
   }
 
   if ( flag_print_version ) {
     {
-      ::std::stringstream msg;
-      msg << PROGRAM_NAME << " " << VERSION << ::std::endl;
-      ::std::cout << msg.str () << ::std::flush;
+      std::ostringstream msg;
+      msg << PROGRAM_NAME << " " << VERSION << std::endl;
+      std::cout << msg.str () << std::flush;
     }
     return -1;
   }
 
   if ( flag_print_copy_info ) {
     {
-      ::std::stringstream msg;
+      std::ostringstream msg;
       msg << PROGRAM_TITLE;
       msg << " - desktop mixer for the Linux sound system ALSA.";
-      msg << ::std::endl;
-      msg << ::std::endl;
+      msg << std::endl;
+      msg << std::endl;
       msg << license_text_short;
-      msg << ::std::endl;
-      ::std::cout << msg.str () << ::std::flush;
+      msg << std::endl;
+      std::cout << msg.str () << std::flush;
     }
     return -1;
   }
@@ -176,13 +154,13 @@ Desktop_Items::parse_cmd_options ( int argc, char * argv[] )
       if ( card_idx_int < 0 ) {
         card_idx_int = 0;
       }
-      ctl_address = QString ( "hw:%1" ).arg ( card_idx_int );
+      ctl_address = QStringLiteral ( "hw:" ) + QString::number ( card_idx_int );
     }
   }
 
   if ( !ctl_address.isEmpty () ) {
     _cmd_opts.start_ctl_address = ctl_address;
-    _dsetup.main_window.mixer_dev.ctl_addr = ctl_address;
+    _dsetup.main_window.mixer_dev.control_address = ctl_address;
   }
 
   return 0;
@@ -191,14 +169,14 @@ Desktop_Items::parse_cmd_options ( int argc, char * argv[] )
 void
 Desktop_Items::parse_message ( QString msg_n )
 {
-  //::std::cout << "Desktop_Items::parse_message " << "\n";
+  // std::cout << "Desktop_Items::parse_message " << "\n";
 
-  QStringList rows ( msg_n.split ( "\n", QString::SkipEmptyParts ) );
+  QStringList rows ( msg_n.split ( "\n", Qt::SkipEmptyParts ) );
 
   for ( int ii = 0; ii < rows.size (); ++ii ) {
     const QString & row ( rows[ ii ] );
 
-    //::std::cout << "row[" << ii << "]: " << row.toLocal8Bit().constData() <<
+    // std::cout << "row[" << ii << "]: " << row.toLocal8Bit().constData() <<
     //"\n";
 
     if ( row.contains ( "raise", Qt::CaseInsensitive ) ) {
@@ -214,7 +192,7 @@ Desktop_Items::parse_message ( QString msg_n )
       }
       if ( !ctl_str.isEmpty () ) {
         if ( _main_mixer == 0 ) {
-          _dsetup.main_window.mixer_dev.ctl_addr = ctl_str;
+          _dsetup.main_window.mixer_dev.control_address = ctl_str;
           tray_mixer_reload_current_mdev ();
         } else {
           _main_mixer->select_ctl ( ctl_str );
@@ -255,15 +233,16 @@ Desktop_Items::start ( bool restore_session_n )
 
   // Startup mixer device
   {
-    QString & ctl_addr ( _dsetup.main_window.mixer_dev.ctl_addr );
+    QSnd::Ctl_Address & ctl_addr =
+        _dsetup.main_window.mixer_dev.control_address;
     if ( _cmd_opts.start_ctl_address.isEmpty () ) {
-      bool use_default ( true );
+      bool use_default = true;
       switch ( _dsetup.start_device_mode ) {
-      case 1:
+      case Desktop_Items_Setup::MIXER_DEV_PREVIOUS:
         // Device should've been set during configuration reading
-        use_default = ctl_addr.isEmpty ();
+        use_default = !ctl_addr.is_valid ();
         break;
-      case 2:
+      case Desktop_Items_Setup::MIXER_DEV_USER:
         ctl_addr = _dsetup.start_user_device;
         use_default = false;
         break;
@@ -271,51 +250,13 @@ Desktop_Items::start ( bool restore_session_n )
         break;
       }
       if ( use_default ) {
-        ctl_addr = "default";
+        ctl_addr = QStringLiteral ( "default" );
       }
     } else {
       ctl_addr = _cmd_opts.start_ctl_address;
     }
   }
 
-  // Slider painter bevelled
-  {
-    ::Wdg::Painter::DS_Slider_Painter_Bevelled * pnt (
-        new ::Wdg::Painter::DS_Slider_Painter_Bevelled );
-    pnt->set_wdg_style_db ( &_wdg_style_db );
-    _image_alloc.install_painter ( pnt );
-  }
-
-  // Switch painter circle
-  {
-    ::Wdg::Painter::DS_Switch_Painter_Circle * pnt (
-        new ::Wdg::Painter::DS_Switch_Painter_Circle );
-    pnt->set_group_variant ( ::Wdg::DS_CIRCLE );
-    pnt->set_wdg_style_db ( &_wdg_style_db );
-    _image_alloc.install_painter ( pnt );
-  }
-  // Switch painter close
-  {
-    ::Wdg::Painter::DS_Switch_Painter_Close * pnt (
-        new ::Wdg::Painter::DS_Switch_Painter_Close );
-    pnt->set_group_variant ( ::Wdg::DS_CLOSE );
-    pnt->set_wdg_style_db ( &_wdg_style_db );
-    _image_alloc.install_painter ( pnt );
-  }
-  // Switch painter SVG
-  {
-    QScopedPointer<::Wdg::Painter::DS_Switch_Painter_SVG > pnt (
-        new ::Wdg::Painter::DS_Switch_Painter_SVG );
-    pnt->set_group_variant ( ::Wdg::DS_SVG_JOINED );
-    pnt->set_wdg_style_db ( &_wdg_style_db );
-    pnt->set_base_dir ( INSTALL_DIR_WIDGETS_GRAPHICS );
-    pnt->set_file_prefix_bg ( "sw_joined_bg_" );
-    pnt->set_file_prefix_handle ( "sw_joined_handle_" );
-    if ( pnt->ready () ) {
-      _image_alloc.install_painter ( pnt.take () );
-    }
-  }
-
   if ( restore_session_n ) {
     // Restore minimized session
     if ( _dsetup.tray_is_minimized ) {
@@ -337,34 +278,40 @@ Desktop_Items::start ( bool restore_session_n )
 void
 Desktop_Items::main_mixer_create ()
 {
-  if ( _main_mixer != 0 ) {
+  if ( _main_mixer ) {
     return;
   }
 
-  _main_mixer = new Main_Window;
+  _main_mixer =
+      std::make_unique< Main_Window > ( &_cards_db, &_mixer_states_db );
   _main_mixer->installEventFilter ( this );
 
-  connect ( _main_mixer,
-            SIGNAL ( sig_quit () ),
+  connect ( _main_mixer.get (),
+            &Main_Window::sig_quit,
             this,
-            SLOT ( quit () ),
+            &Desktop_Items::quit,
             Qt::QueuedConnection );
 
-  connect ( _main_mixer,
-            SIGNAL ( sig_control_changed () ),
+  connect ( _main_mixer.get (),
+            &Main_Window::sig_control_changed,
             this,
-            SLOT ( tray_mixer_reload_current_mdev () ),
+            &Desktop_Items::tray_mixer_reload_current_mdev,
             Qt::QueuedConnection );
 
-  connect ( _main_mixer,
-            SIGNAL ( sig_show_settings () ),
+  connect ( _main_mixer.get (),
+            &Main_Window::sig_show_settings,
             this,
-            SLOT ( show_dialog_settings () ) );
+            &Desktop_Items::show_dialog_settings );
 
-  connect ( _main_mixer,
-            SIGNAL ( sig_show_info () ),
+  connect ( _main_mixer.get (),
+            &Main_Window::sig_show_about,
             this,
-            SLOT ( show_dialog_info () ) );
+            &Desktop_Items::show_dialog_about );
+
+  connect ( _main_mixer.get (),
+            &Main_Window::sig_show_about_qt,
+            this,
+            &Desktop_Items::show_dialog_about_qt );
 
   _main_mixer->set_window_setup ( &_dsetup.main_window );
   _main_mixer->show ();
@@ -373,18 +320,17 @@ Desktop_Items::main_mixer_create ()
 void
 Desktop_Items::main_mixer_destroy ()
 {
-  if ( _main_mixer != 0 ) {
-    delete _main_mixer;
-    _main_mixer = 0;
-    //::std::cout << "Main mixer destroyed\n";
+  if ( _main_mixer ) {
+    _main_mixer.reset ();
+    // std::cout << "Main mixer destroyed\n";
   }
 }
 
 bool
 Desktop_Items::main_mixer_visible ()
 {
-  bool res ( false );
-  if ( _main_mixer != 0 ) {
+  bool res = false;
+  if ( _main_mixer ) {
     res = !_main_mixer->isHidden ();
   }
   return res;
@@ -393,15 +339,25 @@ Desktop_Items::main_mixer_visible ()
 void
 Desktop_Items::main_mixer_close ()
 {
-  if ( _main_mixer != 0 ) {
-    _main_mixer->close ();
+  if ( !_main_mixer ) {
+    return;
   }
+
+  // Make sure the settings dialog receives a close event
+  if ( !_dialog_settings.isNull () ) {
+    _dialog_settings->close ();
+  }
+  if ( !_dialog_about.isNull () ) {
+    _dialog_about->close ();
+  }
+  // Close the main mixer
+  _main_mixer->close ();
 }
 
 void
 Desktop_Items::main_mixer_raise ()
 {
-  if ( _main_mixer == 0 ) {
+  if ( !_main_mixer ) {
     main_mixer_create ();
   }
 
@@ -409,6 +365,7 @@ Desktop_Items::main_mixer_raise ()
   if ( _main_mixer->isMinimized () ) {
     _main_mixer->showNormal ();
   }
+  _main_mixer->activateWindow ();
   _main_mixer->raise ();
 
   _dsetup.tray_is_minimized = false;
@@ -419,8 +376,8 @@ Desktop_Items::main_mixer_raise ()
 void
 Desktop_Items::main_mixer_toggle_by_tray ()
 {
-  bool raise_main ( true );
-  if ( _main_mixer != 0 ) {
+  bool raise_main = true;
+  if ( _main_mixer ) {
     if ( _main_mixer->isActiveWindow () ) {
       raise_main = false;
     }
@@ -457,7 +414,7 @@ Desktop_Items::main_mixer_closed ()
 void
 Desktop_Items::main_mixer_reload_view ()
 {
-  if ( _main_mixer != 0 ) {
+  if ( _main_mixer ) {
     _main_mixer->reload_mixer_view ();
   }
 }
@@ -465,45 +422,45 @@ Desktop_Items::main_mixer_reload_view ()
 void
 Desktop_Items::tray_mixer_create ()
 {
-  if ( _tray_mixer != 0 ) {
+  if ( _tray_mixer ) {
     return;
   }
 
-  _tray_mixer = new Tray_Mixer ( this );
+  _tray_mixer = std::make_unique< Tray::Mixer > ( &_cards_db, this );
 
-  connect ( _tray_mixer,
-            SIGNAL ( sig_toggle_mixer () ),
+  connect ( _tray_mixer.get (),
+            &Tray::Mixer::sig_toggle_mixer,
             this,
-            SLOT ( main_mixer_toggle_by_tray () ) );
+            &Desktop_Items::main_mixer_toggle_by_tray );
 
-  connect ( _tray_mixer,
-            SIGNAL ( sig_quit () ),
+  connect ( _tray_mixer.get (),
+            &Tray::Mixer::sig_quit,
             this,
-            SLOT ( quit () ),
+            &Desktop_Items::quit,
             Qt::QueuedConnection );
 
   // Initialize setup tree values
   _dsetup.tray_view.wheel_degrees = _dsetup.main_window.inputs.wheel_degrees;
-  _dsetup.tray_mdev.current_device = _dsetup.main_window.mixer_dev.ctl_addr;
+  _dsetup.tray_mixer_dev.current_device =
+      _dsetup.main_window.mixer_dev.control_address.addr_str ();
 
   // Install setup tree
-  _tray_mixer->set_mdev_setup ( &_dsetup.tray_mdev );
+  _tray_mixer->set_mixer_dev_setup ( &_dsetup.tray_mixer_dev );
   _tray_mixer->set_view_setup ( &_dsetup.tray_view );
 }
 
 void
 Desktop_Items::tray_mixer_destroy ()
 {
-  if ( _tray_mixer != 0 ) {
-    delete _tray_mixer;
-    _tray_mixer = 0;
+  if ( _tray_mixer ) {
+    _tray_mixer.reset ();
   }
 }
 
 void
 Desktop_Items::tray_mixer_update_visibility ()
 {
-  bool tray_vis ( false );
+  bool tray_vis = false;
 
   if ( !_shutdown ) {
     if ( _dsetup.tray_show_icon ) {
@@ -523,41 +480,38 @@ Desktop_Items::tray_mixer_update_visibility ()
 bool
 Desktop_Items::tray_mixer_visible ()
 {
-  bool res ( false );
-  if ( _tray_mixer != 0 ) {
-    res = _tray_mixer->is_visible ();
+  if ( _tray_mixer ) {
+    return _tray_mixer->is_visible ();
   }
-  return res;
+  return false;
 }
 
 void
 Desktop_Items::tray_mixer_reload_mdev ()
 {
-  if ( _tray_mixer != 0 ) {
-    _tray_mixer->set_mdev_setup ( 0 );
-    _tray_mixer->set_mdev_setup ( &_dsetup.tray_mdev );
+  if ( _tray_mixer ) {
+    _tray_mixer->set_mixer_dev_setup ( nullptr );
+    _tray_mixer->set_mixer_dev_setup ( &_dsetup.tray_mixer_dev );
   }
 }
 
 void
 Desktop_Items::tray_mixer_reload_current_mdev ()
 {
-  const QString & ctl_main ( _dsetup.main_window.mixer_dev.ctl_addr );
-  if ( _dsetup.tray_mdev.current_device != ctl_main ) {
-    _dsetup.tray_mdev.current_device = ctl_main;
-
-    if ( _dsetup.tray_mdev.device_mode ==
-         ::Tray_Mixer_MDev_Setup::MIXER_DEV_CURRENT ) {
-      tray_mixer_reload_mdev ();
-    }
+  _dsetup.tray_mixer_dev.current_device =
+      _dsetup.main_window.mixer_dev.control_address.addr_str ();
+  if ( _dsetup.tray_mixer_dev.device_mode ==
+       Tray::Mixer_Dev_Setup::MIXER_DEV_CURRENT ) {
+    tray_mixer_reload_mdev ();
   }
 }
 
 void
 Desktop_Items::tray_mixer_update_balloon_setup ()
 {
-  if ( _tray_mixer != 0 ) {
-    _tray_mixer->update_balloon_setup ();
+  if ( _tray_mixer ) {
+    _tray_mixer->set_view_setup ( nullptr );
+    _tray_mixer->set_view_setup ( &_dsetup.tray_view );
   }
 }
 
@@ -565,54 +519,56 @@ void
 Desktop_Items::reload_inputs_setup ()
 {
   // Main mixer
-  if ( _main_mixer != 0 ) {
+  if ( _main_mixer ) {
     _main_mixer->reload_mixer_inputs ();
   }
 
   // Tray mixer
   _dsetup.tray_view.wheel_degrees = _dsetup.main_window.inputs.wheel_degrees;
-  if ( _tray_mixer != 0 ) {
-    _tray_mixer->update_balloon_setup ();
+
+  if ( _tray_mixer ) {
+    _tray_mixer->set_view_setup ( nullptr );
+    _tray_mixer->set_view_setup ( &_dsetup.tray_view );
   }
 }
 
 void
 Desktop_Items::show_dialog_settings ()
 {
-  if ( _main_mixer == 0 ) {
+  if ( !_main_mixer ) {
     return;
   }
 
-  if ( _dialog_settings == 0 ) {
-    ::Views::Settings_Dialog * dlg (
-        new ::Views::Settings_Dialog ( _main_mixer ) );
+  if ( _dialog_settings.isNull () ) {
+    Views::Settings_Dialog * dlg =
+        new Views::Settings_Dialog ( _main_mixer.get () );
     dlg->setAttribute ( Qt::WA_DeleteOnClose );
     dlg->set_setup ( &_dsetup );
 
     connect ( dlg,
-              SIGNAL ( sig_change_mixer_view () ),
+              &Views::Settings_Dialog::sig_change_mixer_view,
               this,
-              SLOT ( main_mixer_reload_view () ) );
+              &Desktop_Items::main_mixer_reload_view );
 
     connect ( dlg,
-              SIGNAL ( sig_change_input () ),
+              &Views::Settings_Dialog::sig_change_input,
               this,
-              SLOT ( reload_inputs_setup () ) );
+              &Desktop_Items::reload_inputs_setup );
 
     connect ( dlg,
-              SIGNAL ( sig_change_tray_view () ),
+              &Views::Settings_Dialog::sig_change_tray_view,
               this,
-              SLOT ( tray_mixer_update_visibility () ) );
+              &Desktop_Items::tray_mixer_update_visibility );
 
     connect ( dlg,
-              SIGNAL ( sig_change_tray_mdev () ),
+              &Views::Settings_Dialog::sig_change_tray_mdev,
               this,
-              SLOT ( tray_mixer_reload_mdev () ) );
+              &Desktop_Items::tray_mixer_reload_mdev );
 
     connect ( dlg,
-              SIGNAL ( sig_change_tray_balloon () ),
+              &Views::Settings_Dialog::sig_change_tray_balloon,
               this,
-              SLOT ( tray_mixer_update_balloon_setup () ) );
+              &Desktop_Items::tray_mixer_update_balloon_setup );
 
     _dialog_settings = dlg;
   }
@@ -620,62 +576,64 @@ Desktop_Items::show_dialog_settings ()
 }
 
 void
-Desktop_Items::show_dialog_info ()
+Desktop_Items::show_dialog_about ()
 {
-  if ( _main_mixer == 0 ) {
+  if ( !_main_mixer ) {
     return;
   }
 
-  if ( _dialog_info == 0 ) {
-    ::Views::Info_Dialog * dlg ( new ::Views::Info_Dialog ( _main_mixer ) );
-    dlg->setAttribute ( Qt::WA_DeleteOnClose );
-
-    _dialog_info = dlg;
+  if ( _dialog_about == nullptr ) {
+    _dialog_about = new Views::Info_Dialog ( _main_mixer.get () );
+    _dialog_about->setAttribute ( Qt::WA_DeleteOnClose );
   }
-  _dialog_info->show ();
+  _dialog_about->show ();
+}
+
+void
+Desktop_Items::show_dialog_about_qt ()
+{
+  QApplication::aboutQt ();
 }
 
 void
 Desktop_Items::shutdown ()
 {
-  if ( !_shutdown ) {
-    _shutdown = true;
-    main_mixer_close ();
-    main_mixer_destroy ();
-    tray_mixer_destroy ();
+  if ( _shutdown ) {
+    return;
   }
+  _shutdown = true;
+  main_mixer_close ();
+  main_mixer_destroy ();
+  tray_mixer_destroy ();
 }
 
 void
 Desktop_Items::quit ()
 {
   shutdown ();
-  emit sig_quit ();
+  Q_EMIT sig_quit ();
 }
 
 bool
 Desktop_Items::event ( QEvent * event_n )
 {
-  bool res ( false );
   if ( event_n->type () == _evt_mixer_closed ) {
     main_mixer_closed ();
-    res = true;
-  } else {
-    res = QObject::event ( event_n );
+    return true;
   }
-  return res;
+  return QObject::event ( event_n );
 }
 
 bool
 Desktop_Items::eventFilter ( QObject * obj_n, QEvent * event_n )
 {
-  bool filtered ( false );
-  if ( obj_n == _main_mixer ) {
+  bool filtered = false;
+  if ( obj_n == _main_mixer.get () ) {
     if ( event_n->type () == QEvent::Close ) {
-      //::std::cout << "Close event catched\n";
+      // std::cout << "Close event catched\n";
       _main_mixer->save_state ();
       if ( !_shutdown ) {
-        QEvent * ev_req ( new QEvent ( QEvent::Type ( _evt_mixer_closed ) ) );
+        QEvent * ev_req = new QEvent ( QEvent::Type ( _evt_mixer_closed ) );
         QCoreApplication::postEvent ( this, ev_req );
       }
     }
