@@ -1,27 +1,30 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_desktop_items_hpp__
-#define __INC_desktop_items_hpp__
+#pragma once
 
 #include "cmd_options.hpp"
 #include "desktop_items_setup.hpp"
-#include "dpe/image_allocator.hpp"
-#include "mwdg/mixer_style.hpp"
+#include "mstate/mixer/states_db.hpp"
+#include "qsnd/cards_db.hpp"
 #include <QDialog>
 #include <QObject>
 #include <QPointer>
+#include <memory>
 
 // Forward declaration
-class Tray_Mixer;
 class Main_Window;
 class Dialog_Settings;
+namespace Tray
+{
+class Mixer;
+}
 
 /// @brief Manages all items that appear on the desktop
 ///
 /// The managed window items are
 ///  - Main_Mixer
-///  - Tray_Mixer ( with tray icon )
+///  - Tray::Mixer ( with tray icon )
 ///
 /// All settings are always present in the setup tree.
 /// The setup tree gets initialized in the constructor
@@ -31,16 +34,20 @@ class Desktop_Items : public QObject
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  Desktop_Items ( QObject * parent_n = 0 );
+  // -- Construction
 
-  ~Desktop_Items ();
+  Desktop_Items ( QObject * parent_n = nullptr );
+
+  ~Desktop_Items () override;
 
   /// @brief Options that came from the command line or a second instance
   ///
   const CMD_Options &
-  cmd_opts () const;
+  cmd_opts () const
+  {
+    return _cmd_opts;
+  }
 
   /// @brief Reads options from storage and command line
   ///
@@ -59,82 +66,99 @@ class Desktop_Items : public QObject
   void
   start ( bool restore_session_n = false );
 
-  // Event handling
+  // -- Event handling
 
   bool
-  event ( QEvent * event_n );
+  event ( QEvent * event_n ) override;
 
   bool
-  eventFilter ( QObject * obj_n, QEvent * event_n );
+  eventFilter ( QObject * obj_n, QEvent * event_n ) override;
 
-  // Signals
-  signals:
+  // -- Signals
 
+  Q_SIGNAL
   void
   sig_quit ();
 
-  // Public slots
-  public slots:
+  // -- Public slots
 
   /// @brief Reads messages from other instances
-  ///
+  Q_SLOT
   void
   parse_message ( QString msg_n );
 
   // Main mixer minimize / raise
 
+  Q_SLOT
   void
   main_mixer_raise ();
 
+  Q_SLOT
   void
   main_mixer_close ();
 
+  Q_SLOT
   void
   main_mixer_toggle_by_tray ();
 
   // Dialogs
 
-  void
-  show_dialog_info ();
-
+  Q_SLOT
   void
   show_dialog_settings ();
 
+  Q_SLOT
+  void
+  show_dialog_about ();
+
+  Q_SLOT
+  void
+  show_dialog_about_qt ();
+
   /// @brief Closes and destroy all widgets
+  Q_SLOT
   void
   shutdown ();
 
   /// @brief Shuts down and emits sig_quit()
+  Q_SLOT
   void
   quit ();
 
-  // Protected slots
-  protected slots:
+  protected:
+  // -- Protected slots
 
+  Q_SLOT
   void
   main_mixer_reload_view ();
 
   /// @brief Lets widgets reload the inputs setup from the setup tree
   ///
+  Q_SLOT
   void
   reload_inputs_setup ();
 
   /// @return true if the tray icon is visible
   ///
+  Q_SLOT
   void
   tray_mixer_update_visibility ();
 
+  Q_SLOT
   void
   tray_mixer_reload_mdev ();
 
+  Q_SLOT
   void
   tray_mixer_reload_current_mdev ();
 
+  Q_SLOT
   void
   tray_mixer_update_balloon_setup ();
 
-  // Private methods
   private:
+  // -- Private methods
+
   /// @brief Creates a new main mixer window
   ///
   void
@@ -172,32 +196,21 @@ class Desktop_Items : public QObject
   int
   parse_cmd_options ( int argc, char * argv[] );
 
-  // Private attributes
   private:
+  // -- Attributes
+  int _evt_mixer_closed = 0;
   Desktop_Items_Setup _dsetup;
+  QSnd::Cards_Db _cards_db;
+  MState::Mixer::States_Db _mixer_states_db;
 
-  QPointer< Tray_Mixer > _tray_mixer;
-  QPointer< Main_Window > _main_mixer;
-
-  // Shared storages and settings
-  ::MWdg::Mixer_Style _mixer_style;
-  ::Wdg::DS_Widget_Style_Db _wdg_style_db;
-  ::dpe::Image_Allocator _image_alloc;
+  std::unique_ptr< Tray::Mixer > _tray_mixer;
+  std::unique_ptr< Main_Window > _main_mixer;
 
   // Dialogs
   QPointer< QDialog > _dialog_settings;
-  QPointer< QDialog > _dialog_info;
+  QPointer< QDialog > _dialog_about;
 
   CMD_Options _cmd_opts;
-  int _evt_mixer_closed;
-  bool _started;
-  bool _shutdown;
+  bool _started = false;
+  bool _shutdown = false;
 };
-
-inline const CMD_Options &
-Desktop_Items::cmd_opts () const
-{
-  return _cmd_opts;
-}
-
-#endif
