@@ -1,13 +1,11 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_desktop_items_setup_hpp__
-#define __INC_desktop_items_setup_hpp__
+#pragma once
 
 #include "main_window_setup.hpp"
-#include "tray_mixer_mdev_setup.hpp"
-#include "tray_mixer_view_setup.hpp"
-#include "views/device_selection_view.hpp"
+#include "tray/mixer_dev_setup.hpp"
+#include "tray/view_setup.hpp"
 #include "views/settings_dialog_setup.hpp"
 #include <QString>
 
@@ -15,8 +13,9 @@
 ///
 class Desktop_Items_Setup
 {
-  // Public typedefs
   public:
+  // -- Public types
+
   enum Mixer_Device
   {
     MIXER_DEV_DEFAULT = 0,
@@ -25,31 +24,32 @@ class Desktop_Items_Setup
     MIXER_DEV_LAST = MIXER_DEV_USER
   };
 
-  // Public methods
-  public:
+  // -- Construction
+
   Desktop_Items_Setup ();
 
+  ~Desktop_Items_Setup ();
+
+  // -- Storage
+
   void
   read_from_storage ();
 
   void
   write_to_storage ();
 
-  // Public attributes
   public:
+  // -- Attributes
   // Device to load on startup
-  unsigned int start_device_mode;
+  Mixer_Device start_device_mode = Mixer_Device::MIXER_DEV_DEFAULT;
   QString start_user_device;
 
-  ::Tray_Mixer_MDev_Setup tray_mdev;
-  ::Tray_Mixer_View_Setup tray_view;
-  ::Main_Window_Setup main_window;
-  ::Views::Device_Selection_View_Setup device_selection_view;
-  ::Views::Settings_Dialog_Setup settings_dialog;
+  Tray::Mixer_Dev_Setup tray_mixer_dev;
+  Tray::View_Setup tray_view;
+  Main_Window_Setup main_window;
+  Views::Settings_Dialog_Setup settings_dialog;
 
-  bool tray_on_close;
-  bool tray_show_icon;
-  bool tray_is_minimized;
+  bool tray_on_close = true;
+  bool tray_show_icon = true;
+  bool tray_is_minimized = false;
 };
-
-#endif
