@@ -3,7 +3,6 @@
 
 #include "main_window_setup.hpp"
 
-Main_Window_Setup::Main_Window_Setup ()
-: show_dev_select ( false )
-{
-}
+Main_Window_Setup::Main_Window_Setup () = default;
+
+Main_Window_Setup::~Main_Window_Setup () = default;
