@@ -1,36 +1,37 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_main_window_setup_hpp__
-#define __INC_main_window_setup_hpp__
+#pragma once
 
 #include "mwdg/inputs_setup.hpp"
 #include "mwdg/mixer_device_setup.hpp"
 #include "views/device_selection_view_setup.hpp"
-#include "views/mixer_simple_setup.hpp"
+#include "views/device_settings_dialog_setup.hpp"
+#include "views/mixer_setup.hpp"
 #include <QByteArray>
-#include <QKeySequence>
 
 /// @brief Main_Window_Setup
 ///
 class Main_Window_Setup
 {
-  // Public methods
   public:
+  // -- Construction
+
   Main_Window_Setup ();
 
-  // Public attributes
+  ~Main_Window_Setup ();
+
   public:
-  bool show_dev_select;
+  // -- Attributes
+  bool show_dev_select = true;
   QByteArray window_state;
   QByteArray window_geometry;
   QByteArray splitter_state;
 
-  ::MWdg::Mixer_Device_Setup mixer_dev;
-  ::MWdg::Inputs_Setup inputs;
+  MWdg::Mixer_Device_Setup mixer_dev;
+  MWdg::Inputs_Setup inputs;
 
-  ::Views::Mixer_Simple_Setup mixer_simple;
-  ::Views::Device_Selection_View_Setup dev_select;
+  Views::Mixer_Setup mixer;
+  Views::Device_Selection_View_Setup dev_select;
+  Views::Device_Settings_Dialog_Setup device_settings_dialog;
 };
-
-#endif
