@@ -18,9 +18,7 @@ namespace Views
 {
 
 Settings_Dialog::Settings_Dialog ( QWidget * parent_n, Qt::WindowFlags flags_n )
-: ::Views::Multi_Page_Dialog ( parent_n, flags_n )
-, _dsetup ( 0 )
-, _updating_values ( false )
+: Views::Multi_Page_Dialog ( parent_n, flags_n )
 {
   {
     QString title_str ( tr ( "Settings" ) );
@@ -31,19 +29,18 @@ Settings_Dialog::Settings_Dialog ( QWidget * parent_n, Qt::WindowFlags flags_n )
 
   _vspace = qMax ( 0, fontMetrics ().height () * 2 / 3 );
 
+  add_pages_begin ();
   init_page_startup ();
   init_page_appearance ();
   init_page_input ();
   init_page_sys_tray ();
+  add_pages_end ();
 
   // Update states
   update_inputs_vis_state ();
 }
 
-Settings_Dialog::~Settings_Dialog ()
-{
-  set_setup ( 0 );
-}
+Settings_Dialog::~Settings_Dialog () = default;
 
 void
 Settings_Dialog::init_page_startup ()
@@ -68,7 +65,7 @@ Settings_Dialog::init_page_startup ()
     QLabel * lbl_example ( new QLabel ( tr ( "e.g. hw:0" ) ) );
 
     connect ( _start_btn_grp_device,
-              SIGNAL ( buttonClicked ( int ) ),
+              SIGNAL ( buttonClicked ( QAbstractButton * ) ),
               this,
               SLOT ( change_startup () ) );
 
@@ -111,20 +108,33 @@ Settings_Dialog::init_page_startup ()
 void
 Settings_Dialog::init_page_appearance ()
 {
-  QGroupBox * box_smixer ( new QGroupBox );
-  box_smixer->setTitle ( tr ( "Sliders" ) );
+  QGroupBox * box_sliders ( new QGroupBox );
+  box_sliders->setTitle ( tr ( "Sliders" ) );
   {
     _btn_show_sliders_labels =
         new QCheckBox ( tr ( "Show slider value labels" ) );
-
     connect ( _btn_show_sliders_labels,
               SIGNAL ( toggled ( bool ) ),
               this,
               SLOT ( change_appearance () ) );
 
-    QVBoxLayout * lay_smixer ( new QVBoxLayout );
-    lay_smixer->addWidget ( _btn_show_sliders_labels );
-    box_smixer->setLayout ( lay_smixer );
+    QVBoxLayout * lay_sliders ( new QVBoxLayout );
+    lay_sliders->addWidget ( _btn_show_sliders_labels );
+    box_sliders->setLayout ( lay_sliders );
+  }
+
+  QGroupBox * box_controls ( new QGroupBox );
+  box_controls->setTitle ( tr ( "Controls" ) );
+  {
+    _btn_show_tool_tips = new QCheckBox ( tr ( "Show tooltips" ) );
+    connect ( _btn_show_tool_tips,
+              SIGNAL ( toggled ( bool ) ),
+              this,
+              SLOT ( change_appearance () ) );
+
+    QVBoxLayout * lay_controls ( new QVBoxLayout );
+    lay_controls->addWidget ( _btn_show_tool_tips );
+    box_controls->setLayout ( lay_controls );
   }
 
   // Container widget
@@ -132,7 +142,9 @@ Settings_Dialog::init_page_appearance ()
   {
     QVBoxLayout * lay_wdg ( new QVBoxLayout );
     lay_wdg->setContentsMargins ( 0, 0, 0, 0 );
-    lay_wdg->addWidget ( box_smixer );
+    lay_wdg->addWidget ( box_sliders );
+    lay_wdg->addSpacing ( _vspace );
+    lay_wdg->addWidget ( box_controls );
     lay_wdg->addStretch ( 1 );
     wdg_all->setLayout ( lay_wdg );
   }
@@ -150,7 +162,7 @@ Settings_Dialog::init_page_input ()
     QLabel * lbl_info ( new QLabel (
         tr ( "Number of turns for a slider change from 0% to 100%" ) ) );
 
-    const unsigned int range[ 2 ] = {1, 150};
+    const unsigned int range[ 2 ] = { 1, 150 };
 
     _mwheel_turns_input = new QDoubleSpinBox;
     _mwheel_turns_input->setRange ( range[ 0 ] / 10.0, range[ 1 ] / 10.0 );
@@ -249,7 +261,7 @@ Settings_Dialog::init_page_sys_tray ()
       //: ms - abbreviation for milliseconds
       QLabel * lbl_ms ( new QLabel ( tr ( "ms" ) ) );
 
-      const int range[ 2 ] = {100, 10000};
+      const int range[ 2 ] = { 100, 10000 };
 
       _tray_balloon_time_input = new QSpinBox;
       _tray_balloon_time_input->setRange ( range[ 0 ], range[ 1 ] );
@@ -298,7 +310,7 @@ Settings_Dialog::init_page_sys_tray ()
     QLabel * lbl_example ( new QLabel ( tr ( "e.g. hw:0" ) ) );
 
     connect ( _tray_btn_grp_device,
-              SIGNAL ( buttonClicked ( int ) ),
+              SIGNAL ( buttonClicked ( QAbstractButton * ) ),
               this,
               SLOT ( change_tray_mdev () ) );
 
@@ -347,17 +359,17 @@ Settings_Dialog::init_page_sys_tray ()
 }
 
 void
-Settings_Dialog::set_setup ( ::Desktop_Items_Setup * setup_n )
+Settings_Dialog::set_setup ( Desktop_Items_Setup * setup_n )
 {
-  if ( _dsetup != 0 ) {
-    _dsetup->settings_dialog.page = current_page_idx ();
-  }
-
   _dsetup = setup_n;
 
-  if ( _dsetup != 0 ) {
+  if ( _dsetup != nullptr ) {
+    restoreGeometry ( _dsetup->settings_dialog.window_geometry );
+    restore_splitter_state ( _dsetup->settings_dialog.splitter_state );
+
     update_inputs_values ();
 
+    // Select current page
     if ( _dsetup->settings_dialog.page >= num_pages () ) {
       _dsetup->settings_dialog.page = 0;
     }
@@ -368,7 +380,7 @@ Settings_Dialog::set_setup ( ::Desktop_Items_Setup * setup_n )
 void
 Settings_Dialog::update_inputs_values ()
 {
-  if ( _dsetup == 0 ) {
+  if ( _dsetup == nullptr ) {
     return;
   }
 
@@ -377,7 +389,7 @@ Settings_Dialog::update_inputs_values ()
   // Startup
   {
     unsigned int idx ( _dsetup->start_device_mode );
-    if ( idx > ::Desktop_Items_Setup::MIXER_DEV_LAST ) {
+    if ( idx > Desktop_Items_Setup::MIXER_DEV_LAST ) {
       idx = 0;
     }
     _start_btn_device[ idx ]->setChecked ( true );
@@ -386,7 +398,8 @@ Settings_Dialog::update_inputs_values ()
 
   // Appearance
   _btn_show_sliders_labels->setChecked (
-      _dsetup->main_window.mixer_simple.show_slider_value_labels );
+      _dsetup->main_window.mixer.show_slider_value_labels );
+  _btn_show_tool_tips->setChecked ( _dsetup->main_window.mixer.show_tool_tips );
 
   // Input
   {
@@ -403,13 +416,13 @@ Settings_Dialog::update_inputs_values ()
   _tray_balloon_time_input->setValue ( _dsetup->tray_view.balloon_lifetime );
 
   {
-    unsigned int idx ( _dsetup->tray_mdev.device_mode );
-    if ( idx > ::Tray_Mixer_MDev_Setup::MIXER_DEV_LAST ) {
+    unsigned int idx ( _dsetup->tray_mixer_dev.device_mode );
+    if ( idx > Tray::Mixer_Dev_Setup::MIXER_DEV_LAST ) {
       idx = 0;
     }
     _tray_btn_device[ idx ]->setChecked ( true );
   }
-  _tray_dev_user_edit->setText ( _dsetup->tray_mdev.user_device );
+  _tray_dev_user_edit->setText ( _dsetup->tray_mixer_dev.user_device );
 
   update_inputs_vis_state ();
 
@@ -419,7 +432,8 @@ Settings_Dialog::update_inputs_values ()
 void
 Settings_Dialog::update_inputs_vis_state ()
 {
-  const bool has_setup ( _dsetup != 0 );
+  const bool has_setup ( _dsetup != nullptr );
+  _page_startup->setEnabled ( has_setup );
   _page_appearance->setEnabled ( has_setup );
   _page_input->setEnabled ( has_setup );
   _page_sys_tray->setEnabled ( has_setup );
@@ -429,7 +443,7 @@ Settings_Dialog::update_inputs_vis_state ()
   }
 
   _start_dev_user->setEnabled (
-      ( _dsetup->start_device_mode == ::Desktop_Items_Setup::MIXER_DEV_USER ) );
+      ( _dsetup->start_device_mode == Desktop_Items_Setup::MIXER_DEV_USER ) );
 
   {
     bool flag ( _dsetup->tray_on_close || _dsetup->tray_show_icon );
@@ -439,8 +453,8 @@ Settings_Dialog::update_inputs_vis_state ()
 
   _tray_balloon_time->setEnabled ( _dsetup->tray_view.show_balloon );
 
-  _tray_dev_user->setEnabled ( ( _dsetup->tray_mdev.device_mode ==
-                                 ::Tray_Mixer_MDev_Setup::MIXER_DEV_USER ) );
+  _tray_dev_user->setEnabled ( ( _dsetup->tray_mixer_dev.device_mode ==
+                                 Tray::Mixer_Dev_Setup::MIXER_DEV_USER ) );
 }
 
 void
@@ -458,15 +472,16 @@ Settings_Dialog::wheel_turns_changed ( double value_n )
 void
 Settings_Dialog::change_startup ()
 {
-  if ( ( _dsetup == 0 ) || _updating_values ) {
+  if ( ( _dsetup == nullptr ) || _updating_values ) {
     return;
   }
 
   bool changed ( false );
   int idx = _start_btn_grp_device->checkedId ();
-  if ( ( idx >= 0 ) && ( idx <= ::Desktop_Items_Setup::MIXER_DEV_LAST ) ) {
-    if ( idx != (int)_dsetup->start_device_mode ) {
-      _dsetup->start_device_mode = idx;
+  if ( ( idx >= 0 ) && ( idx <= Desktop_Items_Setup::MIXER_DEV_LAST ) ) {
+    if ( idx != static_cast< int > ( _dsetup->start_device_mode ) ) {
+      _dsetup->start_device_mode =
+          static_cast< Desktop_Items_Setup::Mixer_Device > ( idx );
       changed = true;
     }
   }
@@ -484,28 +499,35 @@ Settings_Dialog::change_startup ()
 void
 Settings_Dialog::change_appearance ()
 {
-  if ( ( _dsetup == 0 ) || _updating_values ) {
+  if ( ( _dsetup == nullptr ) || _updating_values ) {
     return;
   }
 
   bool changed ( false );
   {
-    bool & sflag ( _dsetup->main_window.mixer_simple.show_slider_value_labels );
-    if ( _btn_show_sliders_labels->isChecked () != sflag ) {
+    bool & sflag = _dsetup->main_window.mixer.show_slider_value_labels;
+    if ( sflag != _btn_show_sliders_labels->isChecked () ) {
       sflag = _btn_show_sliders_labels->isChecked ();
       changed = true;
     }
   }
+  {
+    bool & sflag = _dsetup->main_window.mixer.show_tool_tips;
+    if ( sflag != _btn_show_tool_tips->isChecked () ) {
+      sflag = _btn_show_tool_tips->isChecked ();
+      changed = true;
+    }
+  }
   if ( changed ) {
-    //::std::cout << "sig_change_mixer_view()\n";
-    emit sig_change_mixer_view ();
+    // std::cout << "sig_change_mixer_view()\n";
+    Q_EMIT sig_change_mixer_view ();
   }
 }
 
 void
 Settings_Dialog::change_input ()
 {
-  if ( ( _dsetup == 0 ) || _updating_values ) {
+  if ( ( _dsetup == nullptr ) || _updating_values ) {
     return;
   }
 
@@ -520,15 +542,15 @@ Settings_Dialog::change_input ()
   }
 
   if ( changed ) {
-    //::std::cout << "sig_change_input()\n";
-    emit sig_change_input ();
+    // std::cout << "sig_change_input()\n";
+    Q_EMIT sig_change_input ();
   }
 }
 
 void
 Settings_Dialog::change_tray_view ()
 {
-  if ( ( _dsetup == 0 ) || _updating_values ) {
+  if ( ( _dsetup == nullptr ) || _updating_values ) {
     return;
   }
 
@@ -545,16 +567,16 @@ Settings_Dialog::change_tray_view ()
   }
 
   if ( changed ) {
-    //::std::cout << "sig_change_tray_view()\n";
+    // std::cout << "sig_change_tray_view()\n";
     update_inputs_vis_state ();
-    emit sig_change_tray_view ();
+    Q_EMIT sig_change_tray_view ();
   }
 }
 
 void
 Settings_Dialog::change_tray_balloon ()
 {
-  if ( ( _dsetup == 0 ) || _updating_values ) {
+  if ( ( _dsetup == nullptr ) || _updating_values ) {
     return;
   }
 
@@ -575,39 +597,53 @@ Settings_Dialog::change_tray_balloon ()
   }
 
   if ( changed ) {
-    //::std::cout << "sig_change_tray_balloon()\n";
+    // std::cout << "sig_change_tray_balloon()\n";
     update_inputs_vis_state ();
-    emit sig_change_tray_balloon ();
+    Q_EMIT sig_change_tray_balloon ();
   }
 }
 
 void
 Settings_Dialog::change_tray_mdev ()
 {
-  if ( ( _dsetup == 0 ) || _updating_values ) {
+  if ( ( _dsetup == nullptr ) || _updating_values ) {
     return;
   }
 
   bool changed ( false );
 
   int idx = _tray_btn_grp_device->checkedId ();
-  if ( ( idx >= 0 ) && ( idx <= ::Tray_Mixer_MDev_Setup::MIXER_DEV_LAST ) ) {
-    if ( idx != (int)_dsetup->tray_mdev.device_mode ) {
-      _dsetup->tray_mdev.device_mode = idx;
+  if ( ( idx >= 0 ) && ( idx <= Tray::Mixer_Dev_Setup::MIXER_DEV_LAST ) ) {
+    if ( idx != static_cast< int > ( _dsetup->tray_mixer_dev.device_mode ) ) {
+      _dsetup->tray_mixer_dev.device_mode =
+          static_cast< Tray::Mixer_Dev_Setup::Mixer_Device > ( idx );
       changed = true;
     }
   }
 
-  if ( _tray_dev_user_edit->text () != _dsetup->tray_mdev.user_device ) {
-    _dsetup->tray_mdev.user_device = _tray_dev_user_edit->text ();
+  if ( _tray_dev_user_edit->text () != _dsetup->tray_mixer_dev.user_device ) {
+    _dsetup->tray_mixer_dev.user_device = _tray_dev_user_edit->text ();
     changed = true;
   }
 
   if ( changed ) {
-    //::std::cout << "sig_change_tray_mdev()\n";
+    // std::cout << "sig_change_tray_mdev()\n";
     update_inputs_vis_state ();
-    emit sig_change_tray_mdev ();
+    Q_EMIT sig_change_tray_mdev ();
   }
 }
 
+void
+Settings_Dialog::closeEvent ( QCloseEvent * event_n )
+{
+  // Save settings
+  if ( _dsetup != nullptr ) {
+    _dsetup->settings_dialog.page = current_page_idx ();
+    _dsetup->settings_dialog.window_geometry = saveGeometry ();
+    _dsetup->settings_dialog.splitter_state = splitter_state ();
+  }
+
+  Views::Multi_Page_Dialog::closeEvent ( event_n );
+}
+
 } // namespace Views
