@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_views_settings_dialog_hpp__
-#define __INC_views_settings_dialog_hpp__
+#pragma once
 
 #include "views/multi_page_dialog.hpp"
 #include <QButtonGroup>
@@ -27,69 +26,85 @@ namespace Views
 
 /// @brief Settings_Dialog
 ///
-class Settings_Dialog : public ::Views::Multi_Page_Dialog
+class Settings_Dialog : public Views::Multi_Page_Dialog
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  Settings_Dialog ( QWidget * parent_n = 0, Qt::WindowFlags flags_n = 0 );
+  // -- Construction
+
+  Settings_Dialog ( QWidget * parent_n = nullptr,
+                    Qt::WindowFlags flags_n = Qt::WindowFlags () );
 
   ~Settings_Dialog ();
 
   void
-  set_setup ( ::Desktop_Items_Setup * setup_n );
+  set_setup ( Desktop_Items_Setup * setup_n );
 
-  // Signals
-  signals:
+  // -- Signals
 
+  Q_SIGNAL
   void
   sig_change_mixer_view ();
 
+  Q_SIGNAL
   void
   sig_change_input ();
 
+  Q_SIGNAL
   void
   sig_change_tray_view ();
 
+  Q_SIGNAL
   void
   sig_change_tray_mdev ();
 
+  Q_SIGNAL
   void
   sig_change_tray_balloon ();
 
+  Q_SIGNAL
   void
   sig_close ();
 
-  // Protected slots
-  protected slots:
+  protected:
+  // -- Protected slots
 
+  Q_SLOT
   void
   change_startup ();
 
+  Q_SLOT
   void
   change_appearance ();
 
+  Q_SLOT
   void
   change_input ();
 
+  Q_SLOT
   void
   change_tray_view ();
 
+  Q_SLOT
   void
   change_tray_mdev ();
 
+  Q_SLOT
   void
   change_tray_balloon ();
 
+  Q_SLOT
   void
   wheel_turns_changed ( int value_n );
 
+  Q_SLOT
   void
   wheel_turns_changed ( double value_n );
 
-  // Protected methods
   protected:
+  // -- Utility
+
   void
   init_page_startup ();
 
@@ -108,9 +123,14 @@ class Settings_Dialog : public ::Views::Multi_Page_Dialog
   void
   update_inputs_vis_state ();
 
-  // Private attributes
+  // -- Event processing
+
+  void
+  closeEvent ( QCloseEvent * event_n );
+
   private:
-  ::Desktop_Items_Setup * _dsetup;
+  // -- Attributes
+  Desktop_Items_Setup * _dsetup = nullptr;
 
   // Pages
   QWidget * _page_startup;
@@ -126,6 +146,7 @@ class Settings_Dialog : public ::Views::Multi_Page_Dialog
 
   // Page: Appearance
   QCheckBox * _btn_show_sliders_labels;
+  QCheckBox * _btn_show_tool_tips;
 
   // Page: Input
   QString _mwheel_degrees_mask;
@@ -151,10 +172,8 @@ class Settings_Dialog : public ::Views::Multi_Page_Dialog
 
   // Layout & Styling
   QLocale loc;
-  bool _updating_values;
+  bool _updating_values = false;
   unsigned int _vspace;
 };
 
 } // namespace Views
-
-#endif
