@@ -6,9 +6,8 @@
 namespace Views
 {
 
-Settings_Dialog_Setup::Settings_Dialog_Setup ()
-: page ( 0 )
-{
-}
+Settings_Dialog_Setup::Settings_Dialog_Setup () = default;
+
+Settings_Dialog_Setup::~Settings_Dialog_Setup () = default;
 
 } // namespace Views
