@@ -1,8 +1,10 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_views_settings_dialog_setup_hpp__
-#define __INC_views_settings_dialog_setup_hpp__
+#pragma once
+
+#include <QByteArray>
+#include <cstddef>
 
 namespace Views
 {
@@ -11,15 +13,18 @@ namespace Views
 ///
 class Settings_Dialog_Setup
 {
-  // Public methods
   public:
+  // -- Construction
+
   Settings_Dialog_Setup ();
 
-  // Public attributes
+  ~Settings_Dialog_Setup ();
+
   public:
-  unsigned int page;
+  // -- Attributes
+  std::size_t page = 0;
+  QByteArray window_geometry;
+  QByteArray splitter_state;
 };
 
 } // namespace Views
-
-#endif
