@@ -7,14 +7,9 @@
 namespace dpe
 {
 
-Image::Image ()
-: _width ( 0 )
-, _height ( 0 )
-, _stride ( 0 )
-{
-}
+Image::Image () = default;
 
-Image::~Image () {}
+Image::~Image () = default;
 
 void
 Image::clear ()
@@ -40,8 +35,8 @@ Image::set_size ( unsigned int width_n,
 QPixmap *
 Image::convert_to_pixmap ()
 {
-  if ( ( pixmap () == 0 ) || ( !qimage ().isNull () ) ) {
-    _pixmap.reset ( new QPixmap ( QPixmap::fromImage ( _qimage ) ) );
+  if ( ( !pixmap () ) || ( !qimage ().isNull () ) ) {
+    _pixmap = std::make_unique< QPixmap > ( QPixmap::fromImage ( _qimage ) );
     _qimage = QImage ();
   }
   return pixmap ();
