@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_dpe_image_request_hpp__
-#define __INC_dpe_image_request_hpp__
+#pragma once
 
 #include <vector>
 
@@ -17,13 +16,14 @@ class Image_Set_State;
 namespace dpe
 {
 
-/// @brief Image_Request request
+/// @brief Image_Request
 ///
 class Image_Request
 {
-  // Public methods
   public:
-  Image_Request ( ::dpe::Image_Set_Group * group_n );
+  // -- Construction
+
+  Image_Request ( dpe::Image_Set_Group * group_n );
 
   ~Image_Request ();
 
@@ -34,13 +34,11 @@ class Image_Request
   void
   wait_for_finish ();
 
-  // Public attributes
   public:
-  ::dpe::Image_Set_Group * group;
-  ::std::vector<::dpe::Image_Set_Meta * > meta;
-  ::std::vector<::dpe::Image_Set_State * > states;
+  // -- Attributes
+  dpe::Image_Set_Group * group;
+  std::vector< dpe::Image_Set_Meta * > meta;
+  std::vector< dpe::Image_Set_State * > states;
 };
 
 } // namespace dpe
-
-#endif
