@@ -10,15 +10,14 @@ Image_Set_Meta::Image_Set_Meta ( unsigned int num_images_n,
                                  unsigned int group_type_n,
                                  unsigned int type_id_n )
 : type_id ( type_id_n )
-, style_id ( 0 )
-, style_sub_id ( 0 )
 , group_type ( group_type_n )
-, group_variant ( 0 )
 , num_images ( num_images_n )
 {
 }
 
-Image_Set_Meta::~Image_Set_Meta () {}
+Image_Set_Meta::Image_Set_Meta ( const Image_Set_Meta & meta_n ) = default;
+
+Image_Set_Meta::~Image_Set_Meta () = default;
 
 bool
 Image_Set_Meta::matches ( const Image_Set_Meta * meta_n ) const
@@ -27,14 +26,14 @@ Image_Set_Meta::matches ( const Image_Set_Meta * meta_n ) const
            ( meta_n->style_sub_id == style_sub_id ) &&
            ( meta_n->size == size ) && ( meta_n->group_type == group_type ) &&
            ( meta_n->group_variant == group_variant ) &&
-           ( meta_n->num_images == num_images ) );
+           ( meta_n->num_images == num_images ) &&
+           ( meta_n->palette == palette ) );
 }
 
 Image_Set_Meta *
 Image_Set_Meta::new_copy () const
 {
-  Image_Set_Meta * res ( new Image_Set_Meta ( *this ) );
-  return res;
+  return new Image_Set_Meta ( *this );
 }
 
 } // namespace dpe
