@@ -6,40 +6,43 @@
 namespace dpe
 {
 
-Image_Set_State::Image_Set_State ()
-: _num_todo ( 0 )
-, _finished ( false )
-{
-}
+Image_Set_State::Image_Set_State () = default;
+
+Image_Set_State::~Image_Set_State () = default;
 
 void
 Image_Set_State::wait_for_finish ()
 {
   _mutex.lock ();
-  while ( !_finished ) {
-    _cond.wait ( &_mutex );
+  while ( _num_todo != 0 ) {
+    _cond_finish.wait ( &_mutex );
   }
   _mutex.unlock ();
 }
 
 void
-Image_Set_State::init_todo ( unsigned int num_n )
+Image_Set_State::init_todo ( std::size_t num_n )
 {
+  _mutex.lock ();
   _num_todo = num_n;
-  _finished = ( _num_todo == 0 );
+  _mutex.unlock ();
 }
 
 bool
 Image_Set_State::one_done ()
 {
-  bool res = _num_todo.deref ();
-  if ( !res ) {
+  bool finished = false;
+  {
     _mutex.lock ();
-    _finished = true;
+    --_num_todo;
+    finished = ( _num_todo == 0 );
     _mutex.unlock ();
-    _cond.wakeAll ();
   }
-  return res;
+  if ( finished ) {
+    _cond_finish.wakeAll ();
+    return false;
+  }
+  return true;
 }
 
 } // namespace dpe
