@@ -1,13 +1,11 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_dpe_is_state_hpp__
-#define __INC_dpe_is_state_hpp__
+#pragma once
 
-#include <QAtomicInt>
-#include <QList>
 #include <QMutex>
 #include <QWaitCondition>
+#include <cstddef>
 
 namespace dpe
 {
@@ -16,15 +14,18 @@ namespace dpe
 ///
 class Image_Set_State
 {
-  // Public methods
   public:
+  // -- Construction
+
   Image_Set_State ();
 
+  ~Image_Set_State ();
+
   void
   wait_for_finish ();
 
   void
-  init_todo ( unsigned int num_n );
+  init_todo ( std::size_t num_n );
 
   /// @brief To be called by render threads ( thread safe )
   ///
@@ -35,14 +36,11 @@ class Image_Set_State
   bool
   one_done ();
 
-  // Private attributes
   private:
-  QAtomicInt _num_todo;
+  // -- Attributes
   QMutex _mutex;
-  QWaitCondition _cond;
-  bool _finished;
+  QWaitCondition _cond_finish;
+  std::size_t _num_todo = 0;
 };
 
 } // namespace dpe
-
-#endif
