@@ -2,20 +2,22 @@
 /// \copyright See COPYING file.
 
 #include "is_buffer_handle.hpp"
+#include "image_set.hpp"
+#include "image_set_meta.hpp"
 #include "image_set_state.hpp"
+#include <cassert>
 
 namespace dpe
 {
 
 IS_Buffer_Handle::IS_Buffer_Handle ()
-: num_users ( 0 )
-, state ( new ::dpe::Image_Set_State )
+: state ( std::make_unique< dpe::Image_Set_State > () )
 {
 }
 
 IS_Buffer_Handle::~IS_Buffer_Handle ()
 {
-  delete state;
+  assert ( num_users == 0 );
 }
 
 } // namespace dpe
