@@ -1,10 +1,10 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_dpe_is_buffer_handle_hpp__
-#define __INC_dpe_is_buffer_handle_hpp__
+#pragma once
 
-#include <QTime>
+#include <QElapsedTimer>
+#include <memory>
 
 // Forward declaration
 namespace dpe
@@ -21,21 +21,21 @@ namespace dpe
 ///
 class IS_Buffer_Handle
 {
-  // Public methods
   public:
+  // -- Construction
+
   IS_Buffer_Handle ();
 
   ~IS_Buffer_Handle ();
 
-  ::dpe::Image_Set * img_set;
-  ::dpe::Image_Set_Meta * meta;
+  // Public attributes
+  std::unique_ptr< dpe::Image_Set > img_set;
+  std::unique_ptr< dpe::Image_Set_Meta > meta;
 
-  unsigned int num_users;
-  QTime remove_time;
+  std::size_t num_users = 0;
+  QElapsedTimer remove_time;
 
-  ::dpe::Image_Set_State * state;
+  std::unique_ptr< dpe::Image_Set_State > state;
 };
 
 } // namespace dpe
-
-#endif
