@@ -1,12 +1,12 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_dpe_painter_hpp__
-#define __INC_dpe_painter_hpp__
+#pragma once
 
 // Forward declaration
 namespace dpe
 {
+class Image;
 class Image_Set;
 class Image_Set_Meta;
 class Paint_Job;
@@ -19,52 +19,52 @@ namespace dpe
 ///
 class Painter
 {
-  // Public methods
   public:
+  // -- Construction
+
   Painter ( unsigned int group_type_n, unsigned int group_variant_n = 0 );
 
   virtual ~Painter ();
 
-  unsigned int
-  group_type () const;
+  // -- Group
 
   unsigned int
-  group_variant () const;
+  group_type () const
+  {
+    return _group_type;
+  }
+
+  unsigned int
+  group_variant () const
+  {
+    return _group_variant;
+  }
 
   void
   set_group_variant ( unsigned int variant_n );
 
   int
-  check_and_paint ( ::dpe::Paint_Job * pjob_n );
+  check_and_paint ( dpe::Paint_Job * pjob_n );
 
-  // Protected methods
   protected:
+  // -- Protected methods
+
+  /// @brief Allocate the image an fill it with zeros
+  int
+  create_image_data ( dpe::Image * img_n, const dpe::Image_Set_Meta * meta_n );
+
   /// @brief Single image painting method
   ///
   /// @return 0 on success ( no error )
   virtual int
-  paint_image ( ::dpe::Paint_Job * pjob_n ) = 0;
+  paint_image ( dpe::Paint_Job * pjob_n ) = 0;
 
-  // Private attributes
   private:
+  // -- Attributes
   /// @brief Type of the group this painter knows how to paint
   unsigned int _group_type;
   /// @brief Group variant id
   unsigned int _group_variant;
 };
 
-inline unsigned int
-Painter::group_type () const
-{
-  return _group_type;
-}
-
-inline unsigned int
-Painter::group_variant () const
-{
-  return _group_variant;
-}
-
 } // namespace dpe
-
-#endif
