@@ -7,24 +7,25 @@
 #include "paint_job.hpp"
 #include <QColor>
 #include <QImage>
+#include <QRandomGenerator>
 
 namespace dpe
 {
 
 Painter_Simple::Painter_Simple ()
-: ::dpe::Painter ( 0 )
+: dpe::Painter ( 0 )
 {
 }
 
-Painter_Simple::~Painter_Simple () {}
+Painter_Simple::~Painter_Simple () = default;
 
 int
-Painter_Simple::paint_image ( ::dpe::Paint_Job * pjob_n )
+Painter_Simple::paint_image ( dpe::Paint_Job * pjob_n )
 {
-  int res ( 0 );
+  int res = 0;
 
-  ::dpe::Image & img ( pjob_n->img_set->image ( pjob_n->img_idx ) );
-  ::dpe::Image_Set_Meta * meta ( pjob_n->meta );
+  dpe::Image & img ( pjob_n->img_set->image ( pjob_n->img_idx ) );
+  dpe::Image_Set_Meta * meta ( pjob_n->meta );
 
   img.set_size (
       meta->size.width (), meta->size.height (), meta->size.width () * 4 );
@@ -32,11 +33,11 @@ Painter_Simple::paint_image ( ::dpe::Paint_Job * pjob_n )
   {
     QColor col;
     {
-      unsigned int seed ( pjob_n->img_set->num_images () +
-                          pjob_n->img_idx * 10 );
-      seed += time ( 0 );
-      qsrand ( seed );
-      col.setRgb ( qrand () % 256, qrand () % 256, qrand () % 256, 128 );
+      QRandomGenerator rand_gen = QRandomGenerator::securelySeeded ();
+      col.setRgb ( rand_gen.generate () % 256,
+                   rand_gen.generate () % 256,
+                   rand_gen.generate () % 256,
+                   128 );
     }
     img.qimage ().fill ( col.rgba () );
   }
