@@ -8,24 +8,18 @@
 namespace dpe
 {
 
-Painter_Thread::Painter_Thread ( ::dpe::Painter_Thread_Shared & shared_n )
+Painter_Thread::Painter_Thread (
+    const std::shared_ptr< dpe::Painter_Thread_Shared > & shared_n )
 : _shared ( shared_n )
 {
 }
 
+Painter_Thread::~Painter_Thread () = default;
+
 void
 Painter_Thread::run ()
 {
-  while ( true ) {
-    ::dpe::Paint_Job * pjob ( _shared.fetch_job () );
-
-    if ( pjob == 0 ) {
-      // Exit loop on invalid job
-      break;
-    }
-
-    _shared.paint_job ( pjob );
-    _shared.job_finished ( pjob );
+  while ( _shared->process_job () ) {
   }
 }
 
