@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_dpe_paint_thread_hpp__
-#define __INC_dpe_paint_thread_hpp__
+#pragma once
 
 #include <QThread>
 
@@ -20,20 +19,23 @@ namespace dpe
 ///
 class Painter_Thread : public QThread
 {
-  // Public methods
   public:
-  Painter_Thread ( ::dpe::Painter_Thread_Shared & shared_n );
+  // -- Construction
+
+  Painter_Thread (
+      const std::shared_ptr< dpe::Painter_Thread_Shared > & shared_n );
+
+  ~Painter_Thread ();
 
-  // Protected methods
   protected:
+  // -- Protected methods
+
   void
   run ();
 
-  // Private attributes
   private:
-  ::dpe::Painter_Thread_Shared & _shared;
+  // -- Attributes
+  std::shared_ptr< dpe::Painter_Thread_Shared > _shared;
 };
 
 } // namespace dpe
-
-#endif
