@@ -7,10 +7,9 @@
 namespace MWdg
 {
 
-Inputs_Setup::Inputs_Setup ()
-{
-  wheel_degrees = 720;
-}
+Inputs_Setup::Inputs_Setup () = default;
+
+Inputs_Setup::~Inputs_Setup () = default;
 
 void
 Inputs_Setup::update_translation ()
@@ -19,7 +18,7 @@ Inputs_Setup::update_translation ()
 
   //: "s" is an abbreviation for "split" or "separate".
   //: Something like "j" for "joined" or "c" for "channel" may be appropriate,
-  //too.
+  //: too.
   ks_toggle_joined = QCoreApplication::translate ( "MWdg::Inputs_Setup", "s" );
 
   //: "l" is an abbreviation for "level"
