@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_mwdg_inputs_setup_hpp__
-#define __INC_mwdg_inputs_setup_hpp__
+#pragma once
 
 #include <QKeySequence>
 #include <QString>
@@ -10,18 +9,24 @@
 namespace MWdg
 {
 
+/// @brief Inputs_Setup
+///
 class Inputs_Setup
 {
-  // Public methods
   public:
+  // -- Construction
+
   Inputs_Setup ();
 
+  ~Inputs_Setup ();
+
+  // -- Translation
+
   void
   update_translation ();
 
-  // Public attributes
-  public:
-  unsigned int wheel_degrees;
+  // -- Attributes
+  unsigned int wheel_degrees = 720;
 
   QKeySequence ks_toggle_joined;
   QKeySequence ks_level_channels;
@@ -35,5 +40,3 @@ class Inputs_Setup
 };
 
 } // namespace MWdg
-
-#endif
