@@ -1,10 +1,9 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_mwdg_mixer_device_setup_hpp__
-#define __INC_mwdg_mixer_device_setup_hpp__
+#pragma once
 
-#include <QString>
+#include "qsnd/ctl_address.hpp"
 
 namespace MWdg
 {
@@ -13,15 +12,15 @@ namespace MWdg
 ///
 class Mixer_Device_Setup
 {
-  // Public methods
   public:
+  // -- Construction
+
   Mixer_Device_Setup ();
 
-  // Public attributes
-  public:
-  QString ctl_addr;
+  ~Mixer_Device_Setup ();
+
+  // -- Attributes
+  QSnd::Ctl_Address control_address;
 };
 
 } // namespace MWdg
-
-#endif
