@@ -12,11 +12,11 @@ namespace QSnd
 void
 print_alsa_error ( const std::string & prefix, int err_n )
 {
-  ::std::stringstream msg;
+  std::ostringstream msg;
   msg << "[EE] ";
   msg << prefix << ": ";
-  msg << snd_strerror ( err_n ) << ::std::endl;
-  ::std::cerr << msg.str ();
+  msg << snd_strerror ( err_n ) << std::endl;
+  std::cerr << msg.str ();
 }
 
 QString
