@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_qsnd_alsa_config_watcher_hpp__
-#define __INC_qsnd_alsa_config_watcher_hpp__
+#pragma once
 
 #include <QFileSystemWatcher>
 #include <QObject>
@@ -17,27 +16,31 @@ class ALSA_Config_Watcher : public QObject
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  ALSA_Config_Watcher ( ::QObject * parent_n = 0 );
+  // -- Construction
 
-  // Signals
-  signals:
+  ALSA_Config_Watcher ( QObject * parent_n = nullptr );
 
+  ~ALSA_Config_Watcher ();
+
+  // -- Signals
+
+  Q_SIGNAL
   void
   sig_change ();
 
   // Private slots
-  private slots:
-
+  private:
+  Q_SLOT
   void
   change_in_file ( const QString & fl_n );
 
+  Q_SLOT
   void
   change_in_dir ( const QString & fl_n );
 
-  // Private attributes
   private:
+  // -- Attributes
   QFileSystemWatcher _fwatch;
   QString _cfg_system_dir;
   QString _cfg_system_file;
@@ -46,5 +49,3 @@ class ALSA_Config_Watcher : public QObject
 };
 
 } // namespace QSnd
-
-#endif
