@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_alsa_i18n_hpp__
-#define __INC_alsa_i18n_hpp__
+#pragma once
 
 /*
 
@@ -32,6 +31,9 @@ static const char * alsa_i18n_strings[] = {
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Input Source" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Internal Mic" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Int Mic" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Line" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Line Boost" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Loopback Mixing" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Master" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Mic" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Mic Boost" ),
@@ -39,15 +41,14 @@ static const char * alsa_i18n_strings[] = {
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Mic Select" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "PC Speaker" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Phone" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Rear Mic" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Rear Mic Boost" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Side" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Speaker" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Surround" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Treble" ),
     QT_TRANSLATE_NOOP ( "ALSA::Elem_Name", "Video" ),
 
-    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Enabled" ),
-    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Disabled" ),
-
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "1ch" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "2ch" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "3ch" ),
@@ -56,17 +57,19 @@ static const char * alsa_i18n_strings[] = {
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "6ch" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "7ch" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "8ch" ),
-
+    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Disabled" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Enabled" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Front Mic" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Internal Mic" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Line" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic1" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic2" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic3" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Mic4" ),
-
-    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Video" ),
     QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Phone" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Rear Mic" ),
+    QT_TRANSLATE_NOOP ( "ALSA::Enum_Value", "Video" ),
 
     QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Front Left" ),
     QT_TRANSLATE_NOOP ( "ALSA::Channel_Name", "Front Right" ),
@@ -101,5 +104,3 @@ static const char * alsa_i18n_strings[] = {
     QT_TRANSLATE_NOOP ( "ALSA::CTL_Arg_Name", "CTL" ),
 
 };
-
-#endif
