@@ -1,10 +1,8 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_qsnd_qsnd_card_info_hpp__
-#define __INC_qsnd_qsnd_card_info_hpp__
+#pragma once
 
-#include "qsnd/alsa.hpp"
 #include <QString>
 
 namespace QSnd
@@ -19,30 +17,31 @@ class Card_Info
 
   Card_Info ();
 
-  Card_Info ( const int hw_idx_n );
+  Card_Info ( const int card_idx_n );
 
   Card_Info ( const QString & dev_str_n );
 
+  ~Card_Info ();
+
   // -- Setup
 
   void
   clear ();
 
-  int
-  acquire_info ( const int hw_idx_n );
+  /// @return true on success
+  bool
+  acquire_info ( const int card_idx_n );
 
-  int
+  /// @return true on success
+  bool
   acquire_info ( const QString & dev_str_n );
 
-  int
-  acquire_info ( snd_hctl_t * snd_hctl_n );
-
   // -- Accessors
 
   bool
   is_valid () const
   {
-    return ( _index >= 0 );
+    return _is_valid;
   }
 
   int
@@ -90,13 +89,14 @@ class Card_Info
   // -- Comparison operators
 
   bool
-  operator== ( const ::QSnd::Card_Info & cinfo_n ) const;
+  operator== ( const QSnd::Card_Info & cinfo_n ) const;
 
   bool
-  operator!= ( const ::QSnd::Card_Info & cinfo_n ) const;
+  operator!= ( const QSnd::Card_Info & cinfo_n ) const;
 
   private:
   // -- Attributes
+  bool _is_valid = false;
   int _index = -1;
   QString _id;
   QString _driver;
@@ -107,5 +107,3 @@ class Card_Info
 };
 
 } // namespace QSnd
-
-#endif
