@@ -6,21 +6,16 @@
 namespace QSnd
 {
 
-::QEvent::Type evt_update_values_request;
-::QEvent::Type evt_update_values;
-
-::QEvent::Type evt_reload_request;
-::QEvent::Type evt_reload;
+QEvent::Type evt_update_values;
+QEvent::Type evt_signalize_changes;
+QEvent::Type evt_reload;
 
 void
 init_event_types ()
 {
-  evt_update_values_request =
-      static_cast< QEvent::Type > ( QEvent::registerEventType () );
   evt_update_values =
       static_cast< QEvent::Type > ( QEvent::registerEventType () );
-
-  evt_reload_request =
+  evt_signalize_changes =
       static_cast< QEvent::Type > ( QEvent::registerEventType () );
   evt_reload = static_cast< QEvent::Type > ( QEvent::registerEventType () );
 }
