@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_qsnd_udev_device_lookout_hpp__
-#define __INC_qsnd_udev_device_lookout_hpp__
+#pragma once
 
 #include <libudev.h>
 #include <QObject>
@@ -17,39 +16,30 @@ class UDev_Device_Lookout : public QObject
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  UDev_Device_Lookout ( QObject * parent_n = 0 );
+  // -- Construction
+
+  UDev_Device_Lookout ( QObject * parent_n = nullptr );
 
   ~UDev_Device_Lookout ();
 
-  // Signals
-  signals:
+  // -- Signals
 
+  Q_SIGNAL
   void
   sig_change ();
 
-  // Protected slots
-  protected slots:
-
+  // -- Protected slots
+  protected:
+  Q_SLOT
   void
   udev_process ();
 
-  // Private methods
-  private:
-  void
-  udev_init ();
-
-  void
-  udev_close ();
-
-  // Private attributes
   private:
+  // -- Attributes
   // udev device detection
-  ::udev * _udev;
-  ::udev_monitor * _udev_mon;
+  ::udev * _udev = nullptr;
+  ::udev_monitor * _udev_mon = nullptr;
 };
 
 } // namespace QSnd
-
-#endif
