@@ -8,7 +8,7 @@
 #include <unistd.h>
 #include <QFile>
 #include <QLocalSocket>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QSessionManager>
 #include <iostream>
 #include <sstream>
@@ -17,20 +17,13 @@ Single_Application::Single_Application ( int & argc,
                                          char * argv[],
                                          const QString & unique_key_n )
 : QApplication ( argc, argv )
-, _is_running ( false )
-, _local_server ( 0 )
-, _timeout ( 2000 )
 {
   // Unix signal handling
   {
     Unix_Signal_Handler::init_unix_signal_handlers ();
-
-    Unix_Signal_Handler * usigh ( new Unix_Signal_Handler ( this ) );
-
+    Unix_Signal_Handler * usigh = new Unix_Signal_Handler ( this );
     QObject::connect ( usigh, SIGNAL ( sig_int () ), this, SLOT ( quit () ) );
-
     QObject::connect ( usigh, SIGNAL ( sig_hup () ), this, SLOT ( quit () ) );
-
     QObject::connect ( usigh, SIGNAL ( sig_term () ), this, SLOT ( quit () ) );
   }
 
@@ -39,21 +32,21 @@ Single_Application::Single_Application ( int & argc,
   }
 }
 
-Single_Application::~Single_Application () {}
+Single_Application::~Single_Application () = default;
 
 void
 Single_Application::commitData ( QSessionManager & manager_n )
 {
-  //::std::cout << "Single_Application::commitData\n";
-  emit commitDataRequest ( manager_n );
+  // std::cout << "Single_Application::commitData\n";
+  Q_EMIT commitDataRequest ( manager_n );
 }
 
 void
 Single_Application::saveState ( QSessionManager & manager_n )
 {
-  //::std::cout << "Single_Application::saveState\n";
+  // std::cout << "Single_Application::saveState\n";
   manager_n.setRestartHint ( QSessionManager::RestartIfRunning );
-  emit saveStateRequest ( manager_n );
+  Q_EMIT saveStateRequest ( manager_n );
 }
 
 bool
@@ -65,10 +58,7 @@ Single_Application::set_unique_key ( const QString & unique_key_n )
 
   // Clear
   {
-    if ( _local_server != 0 ) {
-      delete _local_server;
-      _local_server = 0;
-    }
+    _local_server.reset ();
     _is_running = false;
   }
 
@@ -82,7 +72,7 @@ Single_Application::set_unique_key ( const QString & unique_key_n )
   // Adjust com key
   _com_key.replace ( "-", "_" );
   _com_key.replace ( ".", "_" );
-  _com_key.replace ( QRegExp ( "[^A-Za-z0-9_]" ), QString () );
+  _com_key.replace ( QRegularExpression ( "[^A-Za-z0-9_]" ), QString () );
   {
     QString com_suff ( "_" );
 
@@ -114,21 +104,22 @@ Single_Application::set_unique_key ( const QString & unique_key_n )
       if ( !_is_running ) {
         // Connection failed
         {
-          ::std::stringstream msg;
-          msg << "[WW] SApp: Existing socket does not reply.";
-          msg << ::std::endl;
-          msg << "[WW] SApp: Removing broken socket: ";
+          std::ostringstream msg;
+          msg << "[WW] Single_Application: Existing socket does not reply.";
+          msg << std::endl;
+          msg << "[WW] Single_Application: Removing broken socket: ";
           msg << _com_file.toLocal8Bit ().constData ();
-          msg << ::std::endl;
-          ::std::cerr << msg.str ();
+          msg << std::endl;
+          std::cerr << msg.str ();
         }
         // Remove dead socket file
         if ( !com_fl.remove () ) {
           _is_running = true;
           {
-            ::std::stringstream msg;
-            msg << "[WW] Removing socket failed" << ::std::endl;
-            ::std::cerr << msg.str ();
+            std::ostringstream msg;
+            msg << "[WW] Single_Application: Removing socket failed"
+                << std::endl;
+            std::cerr << msg.str ();
           }
         }
       }
@@ -138,9 +129,9 @@ Single_Application::set_unique_key ( const QString & unique_key_n )
   if ( !_is_running ) {
     // Create a local server and listen to incomming messages from other
     // instances
-    _local_server = new QLocalServer ( this );
+    _local_server.reset ( new QLocalServer ( this ) );
     if ( _local_server->listen ( _com_file ) ) {
-      connect ( _local_server,
+      connect ( _local_server.get (),
                 SIGNAL ( newConnection () ),
                 this,
                 SLOT ( new_client () ) );
@@ -148,15 +139,14 @@ Single_Application::set_unique_key ( const QString & unique_key_n )
       QString err ( _local_server->errorString () );
       if ( !err.isEmpty () ) {
         {
-          ::std::stringstream msg;
-          msg << "[EE] SApp: QLocalServer::listen" << ::std::endl;
+          std::ostringstream msg;
+          msg << "[EE] Single_Application: QLocalServer::listen" << std::endl;
           msg << "[EE] " << err.toLocal8Bit ().constData ();
-          msg << ::std::endl;
-          ::std::cerr << msg.str ();
+          msg << std::endl;
+          std::cerr << msg.str ();
         }
       }
-      delete _local_server;
-      _local_server = 0;
+      _local_server.reset ();
       _is_running = true;
     }
   }
@@ -167,14 +157,14 @@ Single_Application::set_unique_key ( const QString & unique_key_n )
 void
 Single_Application::clear_dead_clients ()
 {
-  //::std::cout << "Single_Application::clear_dead_clients\n";
+  // std::cout << "Single_Application::clear_dead_clients\n";
 
-  QLinkedList< Client >::iterator iter ( _clients.begin () );
+  std::list< Client >::iterator iter = _clients.begin ();
   while ( iter != _clients.end () ) {
-    bool remove ( false );
+    bool remove = false;
 
-    Client & cln ( *iter );
-    if ( cln.socket != 0 ) {
+    Client & cln = *iter;
+    if ( cln.socket != nullptr ) {
       if ( cln.socket->state () == QLocalSocket::UnconnectedState ) {
         delete cln.socket;
         publish_message ( cln.data );
@@ -183,7 +173,7 @@ Single_Application::clear_dead_clients ()
     }
 
     if ( remove ) {
-      //::std::cout << "Single_Application::clear_dead_clients - removing\n";
+      // std::cout << "Single_Application::clear_dead_clients - removing\n";
       iter = _clients.erase ( iter );
     } else {
       ++iter;
@@ -194,14 +184,14 @@ Single_Application::clear_dead_clients ()
 void
 Single_Application::read_clients_data ()
 {
-  //::std::cout << "Single_Application::read_clients_data\n";
+  // std::cout << "Single_Application::read_clients_data\n";
 
-  QLinkedList< Client >::iterator iter ( _clients.begin () );
+  std::list< Client >::iterator iter ( _clients.begin () );
   while ( iter != _clients.end () ) {
     Client & cln ( *iter );
-    if ( cln.socket != 0 ) {
+    if ( cln.socket != nullptr ) {
       if ( cln.socket->bytesAvailable () > 0 ) {
-        const int limit ( 1024 * 4 );
+        const int limit = 1024 * 4;
         cln.data.append ( cln.socket->read ( limit ) );
         if ( cln.data.size () >= limit ) {
           // Publish to avoid buffer size explosion
@@ -216,8 +206,8 @@ Single_Application::read_clients_data ()
 void
 Single_Application::new_client ()
 {
-  QLocalSocket * lsocket ( _local_server->nextPendingConnection () );
-  if ( lsocket != 0 ) {
+  QLocalSocket * lsocket = _local_server->nextPendingConnection ();
+  if ( lsocket != nullptr ) {
 
     connect (
         lsocket, SIGNAL ( readyRead () ), this, SLOT ( read_clients_data () ) );
@@ -231,7 +221,7 @@ Single_Application::new_client ()
     {
       Client cln;
       cln.socket = lsocket;
-      _clients.append ( cln );
+      _clients.push_back ( cln );
     }
 
     read_clients_data ();
@@ -243,7 +233,7 @@ Single_Application::publish_message ( QByteArray & data_n )
 {
   if ( data_n.size () > 0 ) {
     _latest_message = data_n.constData ();
-    emit sig_message_available ( _latest_message );
+    Q_EMIT sig_message_available ( _latest_message );
     data_n.clear ();
   }
 }
@@ -255,7 +245,7 @@ Single_Application::send_message ( const QString & msg_n )
     return false;
   }
 
-  bool res ( false );
+  bool res = false;
 
   QLocalSocket lsocket ( this );
   lsocket.connectToServer ( _com_file, QIODevice::WriteOnly );
@@ -267,11 +257,11 @@ Single_Application::send_message ( const QString & msg_n )
       QString err ( lsocket.errorString () );
       if ( !err.isEmpty () ) {
         {
-          ::std::stringstream msg;
-          msg << "[EE] SApp: send_message" << ::std::endl;
+          std::ostringstream msg;
+          msg << "[EE] Single_Application: send_message" << std::endl;
           msg << "[EE] " << err.toLocal8Bit ().constData ();
-          msg << ::std::endl;
-          ::std::cerr << msg.str ();
+          msg << std::endl;
+          std::cerr << msg.str ();
         }
       }
     }
@@ -280,11 +270,11 @@ Single_Application::send_message ( const QString & msg_n )
     QString err ( lsocket.errorString () );
     if ( !err.isEmpty () ) {
       {
-        ::std::stringstream msg;
-        msg << "[EE] SApp: send_message" << ::std::endl;
+        std::ostringstream msg;
+        msg << "[EE] Single_Application: send_message" << std::endl;
         msg << "[EE] " << err.toLocal8Bit ().constData ();
-        msg << ::std::endl;
-        ::std::cerr << msg.str ();
+        msg << std::endl;
+        std::cerr << msg.str ();
       }
     }
   }
