@@ -1,46 +1,58 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_single_application_hpp__
-#define __INC_single_application_hpp__
+#pragma once
 
 #include <QApplication>
-#include <QLinkedList>
 #include <QLocalServer>
 #include <QPointer>
+#include <list>
+#include <memory>
 
+/// @brief Application with single instance support
+///
 class Single_Application : public QApplication
 {
   Q_OBJECT
 
-  // Public methods
   public:
+  // -- Construction
+
   Single_Application ( int & argc,
                        char * argv[],
                        const QString & unique_key_n = QString () );
 
   ~Single_Application ();
 
-  // Unique key
+  // -- Unique key
 
   const QString &
-  unique_key () const;
+  unique_key () const
+  {
+    return _unique_key;
+  }
 
   bool
   set_unique_key ( const QString & unique_key_n );
 
   bool
-  is_running () const;
+  is_running () const
+  {
+    return _is_running;
+  }
 
-  // Message
+  // -- Message
 
   bool
   send_message ( const QString & msg_n );
 
   const QString
-  latest_message () const;
+  latest_message () const
+  {
+    return _latest_message;
+  }
 
-  // Session management
+  // -- Session management
 
   void
   commitData ( QSessionManager & manager_n );
@@ -48,38 +60,41 @@ class Single_Application : public QApplication
   void
   saveState ( QSessionManager & manager_n );
 
-  // Signals
-  signals:
+  // -- Signals
 
+  Q_SIGNAL
   void
   sig_message_available ( QString mesg_n );
 
-  // Protected slots
-  protected slots:
-
+  // -- Protected slots
+  protected:
+  Q_SLOT
   void
   new_client ();
 
+  Q_SLOT
   void
   read_clients_data ();
 
+  Q_SLOT
   void
   clear_dead_clients ();
 
-  // Protected methods
   protected:
+  // -- Protected methods
+
   void
   publish_message ( QByteArray & data_n );
 
-  // Private attributes
   private:
-  bool _is_running;
+  // -- Attributes
+  bool _is_running = false;
   QString _unique_key;
   QString _com_key;
   QString _com_file;
   QString _latest_message;
 
-  QLocalServer * _local_server;
+  std::unique_ptr< QLocalServer > _local_server;
 
   struct Client
   {
@@ -87,27 +102,7 @@ class Single_Application : public QApplication
     QByteArray data;
   };
 
-  QLinkedList< Client > _clients;
+  std::list< Client > _clients;
 
-  const unsigned int _timeout;
+  const unsigned int _timeout = 2000;
 };
-
-inline bool
-Single_Application::is_running () const
-{
-  return _is_running;
-}
-
-inline const QString &
-Single_Application::unique_key () const
-{
-  return _unique_key;
-}
-
-inline const QString
-Single_Application::latest_message () const
-{
-  return _latest_message;
-}
-
-#endif
