@@ -129,7 +129,7 @@ Unix_Signal_Handler::signal_handler_term ( int )
 void
 Unix_Signal_Handler::sev_handle_sig_int ()
 {
-  //::std::cout << "Unix_Signal_Handler::sev_handle_sig_int\n";
+  // std::cout << "Unix_Signal_Handler::sev_handle_sig_int\n";
 
   _sn_int->setEnabled ( false );
   char tmp;
@@ -138,7 +138,7 @@ Unix_Signal_Handler::sev_handle_sig_int ()
     qFatal ( "Unix_Signal_Handler: Reading from SIGINT socket failed" );
   }
 
-  emit sig_int ();
+  Q_EMIT sig_int ();
 
   _sn_int->setEnabled ( true );
 }
@@ -146,7 +146,7 @@ Unix_Signal_Handler::sev_handle_sig_int ()
 void
 Unix_Signal_Handler::sev_handle_sig_hup ()
 {
-  //::std::cout << "Unix_Signal_Handler::sev_handle_sig_hup\n";
+  // std::cout << "Unix_Signal_Handler::sev_handle_sig_hup\n";
 
   _sn_hup->setEnabled ( false );
   char tmp;
@@ -155,7 +155,7 @@ Unix_Signal_Handler::sev_handle_sig_hup ()
     qFatal ( "Unix_Signal_Handler: Reading from SIGHUP socket failed" );
   }
 
-  emit sig_hup ();
+  Q_EMIT sig_hup ();
 
   _sn_hup->setEnabled ( true );
 }
@@ -163,7 +163,7 @@ Unix_Signal_Handler::sev_handle_sig_hup ()
 void
 Unix_Signal_Handler::sev_handle_sig_term ()
 {
-  //::std::cout << "Unix_Signal_Handler::sev_handle_sig_term\n";
+  // std::cout << "Unix_Signal_Handler::sev_handle_sig_term\n";
 
   _sn_term->setEnabled ( false );
   char tmp;
@@ -172,7 +172,7 @@ Unix_Signal_Handler::sev_handle_sig_term ()
     qFatal ( "Unix_Signal_Handler: Reading from SIGTERM socket failed" );
   }
 
-  emit sig_term ();
+  Q_EMIT sig_term ();
 
   _sn_term->setEnabled ( true );
 }
