@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_unix_signal_handler_hpp__
-#define __INC_unix_signal_handler_hpp__
+#pragma once
 
 #include <QObject>
 #include <memory>
@@ -14,8 +13,9 @@ class Unix_Signal_Handler : public QObject
 {
   Q_OBJECT
 
-  // Public methods
   public:
+  // -- Construction
+
   Unix_Signal_Handler ( QObject * parent_n );
 
   ~Unix_Signal_Handler ();
@@ -23,7 +23,7 @@ class Unix_Signal_Handler : public QObject
   static int
   init_unix_signal_handlers ();
 
-  // Unix signal handlers.
+  // -- Unix signal handlers.
 
   static void
   signal_handler_int ( int unused_n );
@@ -34,39 +34,41 @@ class Unix_Signal_Handler : public QObject
   static void
   signal_handler_term ( int unused_n );
 
-  // Signals
-  signals:
+  // -- Signals
 
+  Q_SIGNAL
   void
   sig_int ();
 
+  Q_SIGNAL
   void
   sig_hup ();
 
+  Q_SIGNAL
   void
   sig_term ();
 
-  // Public slots
-  public slots:
+  // -- Public slots
 
+  Q_SLOT
   void
   sev_handle_sig_int ();
 
+  Q_SLOT
   void
   sev_handle_sig_hup ();
 
+  Q_SLOT
   void
   sev_handle_sig_term ();
 
-  // Private attributes
   private:
+  // -- Attributes
   static int _sig_int_fds[ 2 ];
   static int _sig_hup_fds[ 2 ];
   static int _sig_term_fds[ 2 ];
 
-  ::std::unique_ptr< QSocketNotifier > _sn_int;
-  ::std::unique_ptr< QSocketNotifier > _sn_hup;
-  ::std::unique_ptr< QSocketNotifier > _sn_term;
+  std::unique_ptr< QSocketNotifier > _sn_int;
+  std::unique_ptr< QSocketNotifier > _sn_hup;
+  std::unique_ptr< QSocketNotifier > _sn_term;
 };
-
-#endif
