@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_views_basic_dialog_hpp__
-#define __INC_views_basic_dialog_hpp__
+#pragma once
 
 #include <QDialog>
 #include <QLabel>
@@ -18,31 +17,34 @@ class Basic_Dialog : public QDialog
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  Basic_Dialog ( QWidget * parent_n = 0, Qt::WindowFlags flags_n = 0 );
+  // -- Construction
+
+  Basic_Dialog ( QWidget * parent_n = nullptr,
+                 Qt::WindowFlags flags_n = Qt::WindowFlags () );
 
   ~Basic_Dialog ();
 
+  // -- Setup
+
   void
   set_title_str ( const QString & str_n );
 
   void
   set_central_widget ( QWidget * wdg_n );
 
-  QLabel *
-  create_title_widget ( const QString & txt_n );
+  protected:
+  // -- Utility
 
+  /// @brief Creates a close button
   QPushButton *
   create_close_button ();
 
-  // Private attributes
   private:
+  // -- Attributes
   // Pages
-  QLabel * _lbl_title;
-  QVBoxLayout * _lay_main;
+  QLabel * _lbl_title = nullptr;
+  QVBoxLayout * _lay_main = nullptr;
 };
 
 } // namespace Views
-
-#endif
