@@ -12,11 +12,8 @@ namespace Views
 
 View_Base::View_Base ( QWidget * parent_n )
 : QWidget ( parent_n )
-, _mdev_setup ( 0 )
-, _inputs_setup ( 0 )
-, _message_wdg ( 0 )
 {
-  _message_wdg = new ::Views::Message_Widget ( this );
+  _message_wdg = new Views::Message_Widget ( this );
   _message_wdg->hide ();
 
   _lay_stack = new QStackedLayout;
@@ -30,16 +27,16 @@ View_Base::View_Base ( QWidget * parent_n )
 View_Base::~View_Base () {}
 
 void
-View_Base::set_mdev_setup ( const ::MWdg::Mixer_Device_Setup * setup_n )
+View_Base::set_mixer_dev_setup ( const MWdg::Mixer_Device_Setup * setup_n )
 {
-  //::std::cout << "View_Base::set_mdev_setup: " << setup_n << "\n";
-  _mdev_setup = setup_n;
+  // std::cout << "View_Base::set_mixer_dev_setup: " << setup_n << "\n";
+  _mixer_dev_setup = setup_n;
 }
 
 void
-View_Base::set_inputs_setup ( const ::MWdg::Inputs_Setup * setup_n )
+View_Base::set_inputs_setup ( const MWdg::Inputs_Setup * setup_n )
 {
-  //::std::cout << "View_Base::set_inputs_setup: " << setup_n << "\n";
+  // std::cout << "View_Base::set_inputs_setup: " << setup_n << "\n";
   _inputs_setup = setup_n;
 }
 
