@@ -6,12 +6,8 @@
 namespace Views
 {
 
-View_Base_Setup::View_Base_Setup ()
-: wdg_style_db ( 0 )
-, image_alloc ( 0 )
-{
-}
+View_Base_Setup::View_Base_Setup () = default;
 
-View_Base_Setup::~View_Base_Setup () {}
+View_Base_Setup::~View_Base_Setup () = default;
 
 } // namespace Views
