@@ -4,12 +4,14 @@
 #include "view_utility.hpp"
 #include "qastools_config.hpp"
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QFileInfo>
-#include <QLabel>
+#include <QGuiApplication>
 #include <QLibraryInfo>
 #include <QLocale>
+#include <QScreen>
 #include <QTranslator>
+#include <iostream>
+#include <memory>
 
 namespace Views
 {
@@ -18,29 +20,23 @@ void
 load_translators ( QApplication * app_n )
 {
   // Application translators setup
+  auto add_trans = [ app_n ] ( const QString & filename_n,
+                               const QString & dir_n ) {
+    auto translator = std::make_unique< QTranslator > ( app_n );
+    if ( translator->load ( filename_n, dir_n ) ) {
+      app_n->installTranslator ( translator.release () );
+    }
+  };
   {
-    QTranslator * trans_qt ( new QTranslator ( app_n ) );
-    QTranslator * trans_default ( new QTranslator ( app_n ) );
-    QTranslator * trans_local ( new QTranslator ( app_n ) );
-    {
-      QString l10n_db ( "qt_" );
-      l10n_db.append ( QLocale::system ().name () );
-      trans_qt->load (
-          l10n_db, QLibraryInfo::location ( QLibraryInfo::TranslationsPath ) );
-    }
-    {
-      QString l10n_db ( L10N_PREFIX );
-      l10n_db.append ( "default" );
-      trans_default->load ( l10n_db, INSTALL_DIR_L10N );
-    }
-    {
-      QString l10n_db ( L10N_PREFIX );
-      l10n_db.append ( QLocale::system ().name () );
-      trans_local->load ( l10n_db, INSTALL_DIR_L10N );
-    }
-    app_n->installTranslator ( trans_qt );
-    app_n->installTranslator ( trans_default );
-    app_n->installTranslator ( trans_local );
+    QString l10n_db ( "qt_" );
+    l10n_db.append ( QLocale::system ().name () );
+    add_trans ( l10n_db,
+                QLibraryInfo::path ( QLibraryInfo::TranslationsPath ) );
+  }
+  {
+    QString l10n_db ( L10N_PREFIX );
+    l10n_db.append ( QLocale::system ().name () );
+    add_trans ( l10n_db, INSTALL_DIR_L10N );
   }
 }
 
@@ -72,10 +68,26 @@ load_application_icon ( QApplication * app_n, const QString & fallback_n )
 }
 
 bool
-win_default_geometry ( QRect & rect_n )
+win_default_geometry ( const QMainWindow * mwin_n, QRect & rect_n )
 {
-  const unsigned int aspect[ 2 ] = {16, 9};
-  const QRect ravail ( QApplication::desktop ()->availableGeometry () );
+  const unsigned int aspect[ 2 ] = { 16, 9 };
+  QRect ravail;
+  {
+    QScreen * screen = mwin_n->screen ();
+    if ( screen == nullptr ) {
+      QCoreApplication * core_app = QCoreApplication::instance ();
+      if ( core_app != nullptr ) {
+        QGuiApplication * gui_app =
+            dynamic_cast< QGuiApplication * > ( core_app );
+        if ( gui_app != nullptr ) {
+          screen = gui_app->primaryScreen ();
+        }
+      }
+    }
+    if ( screen != nullptr ) {
+      ravail = screen->availableGeometry ();
+    }
+  }
   const bool res ( ravail.isValid () );
   if ( res ) {
     QSize rsize;
@@ -113,10 +125,10 @@ win_default_geometry ( QRect & rect_n )
 }
 
 bool
-win_default_size ( QSize & size_n )
+win_default_size ( const QMainWindow * mwin_n, QSize & size_n )
 {
   QRect rhint;
-  if ( ::Views::win_default_geometry ( rhint ) ) {
+  if ( Views::win_default_geometry ( mwin_n, rhint ) ) {
     if ( size_n.width () < rhint.width () ) {
       size_n.setWidth ( rhint.width () );
     }
@@ -132,7 +144,7 @@ void
 resize_to_default ( QMainWindow * mwin_n )
 {
   QRect wrect;
-  if ( win_default_geometry ( wrect ) ) {
+  if ( win_default_geometry ( mwin_n, wrect ) ) {
     mwin_n->resize ( wrect.size () );
     mwin_n->move ( wrect.topLeft () );
   } else {
