@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_views_view_utility_hpp__
-#define __INC_views_view_utility_hpp__
+#pragma once
 
 #include <QMainWindow>
 #include <QWidget>
@@ -18,15 +17,13 @@ load_application_icon ( QApplication * app_n, const QString & fallback_n );
 
 /// @return true on successful size determination
 bool
-win_default_geometry ( QRect & rect_n );
+win_default_geometry ( const QMainWindow * mwin_n, QRect & rect_n );
 
 /// @return true on successful size determination
 bool
-win_default_size ( QSize & size_n );
+win_default_size ( const QMainWindow * mwin_n, QSize & size_n );
 
 void
 resize_to_default ( QMainWindow * mwin_n );
 
 } // namespace Views
-
-#endif
