@@ -17,7 +17,7 @@ col_mix ( const QColor & col_1, const QColor & col_2, int w_1, int w_2 )
   com1[ 2 ] = col_1.green ();
   com1[ 3 ] = col_1.blue ();
 
-  for ( int ii = 0; ii < 4; ++ii ) {
+  for ( std::size_t ii = 0; ii < 4; ++ii ) {
     com1[ ii ] *= w_1;
   }
 
@@ -28,18 +28,18 @@ col_mix ( const QColor & col_1, const QColor & col_2, int w_1, int w_2 )
     com2[ 2 ] = col_2.green ();
     com2[ 3 ] = col_2.blue ();
 
-    for ( int ii = 0; ii < 4; ++ii ) {
+    for ( std::size_t ii = 0; ii < 4; ++ii ) {
       com2[ ii ] *= w_2;
     }
 
     // Mix
-    for ( int ii = 0; ii < 4; ++ii ) {
+    for ( std::size_t ii = 0; ii < 4; ++ii ) {
       com1[ ii ] += com2[ ii ];
     }
   }
 
   // Rescale
-  for ( int ii = 0; ii < 4; ++ii ) {
+  for ( std::size_t ii = 0; ii < 4; ++ii ) {
     com1[ ii ] /= wsum;
   }
 
