@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_wdg_color_methods_hpp__
-#define __INC_wdg_color_methods_hpp__
+#pragma once
 
 #include <QColor>
 
@@ -13,5 +12,3 @@ QColor
 col_mix ( const QColor & col_1, const QColor & col_2, int w_1, int w_2 );
 
 } // namespace Wdg
-
-#endif
