@@ -9,9 +9,7 @@ namespace Wdg
 
 Cubic_Curve::Cubic_Curve ()
 {
-  for ( int ii = 0; ii < 4; ++ii ) {
-    _coeff[ ii ] = 0.0;
-  }
+  _coeff.fill ( 0.0 );
 }
 
 void
