@@ -1,18 +1,26 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_cubic_curve_hpp__
-#define __INC_cubic_curve_hpp__
+#pragma once
+
+#include <array>
 
 namespace Wdg
 {
 
+/// @brief Cubic_Curve
+///
 class Cubic_Curve
 {
-  // Public methods
   public:
+  // -- Construction
+
   Cubic_Curve ();
 
+  ~Cubic_Curve () = default;
+
+  // -- Evaluation
+
   double
   eval ( double pos_n ) const;
 
@@ -22,11 +30,9 @@ class Cubic_Curve
   void
   set_params ( double x0_n, double v0_n, double x1_n, double time_n );
 
-  // Private attributes
   private:
-  double _coeff[ 4 ];
+  // -- Attributes
+  std::array< double, 4 > _coeff;
 };
 
 } // namespace Wdg
-
-#endif
