@@ -14,16 +14,36 @@ Label_Elide::Label_Elide ( QWidget * parent_n )
 {
 }
 
+Label_Elide::~Label_Elide () = default;
+
 QSize
 Label_Elide::minimumSizeHint () const
 {
-  return QSize ( 0, fontMetrics ().height () );
+  QSize res ( 0, fontMetrics ().height () );
+  {
+    const QMargins mgs = contentsMargins ();
+    res.rwidth () += mgs.left ();
+    res.rwidth () += mgs.right ();
+    res.rheight () += mgs.top ();
+    res.rheight () += mgs.bottom ();
+  }
+  return res;
 }
 
 QSize
 Label_Elide::sizeHint () const
 {
-  QSize res ( fontMetrics ().width ( text () ), fontMetrics ().height () );
+  // The offset is to fix a too small bounding rect.
+  const int offset = 2;
+  QSize res ( fontMetrics ().boundingRect ( text () ).width () + offset,
+              fontMetrics ().height () );
+  {
+    const QMargins mgs = contentsMargins ();
+    res.rwidth () += mgs.left ();
+    res.rwidth () += mgs.right ();
+    res.rheight () += mgs.top ();
+    res.rheight () += mgs.bottom ();
+  }
   return res;
 }
 
@@ -61,7 +81,9 @@ Label_Elide::setElideMode ( Qt::TextElideMode mode_n )
 void
 Label_Elide::update_text_elided ()
 {
-  _text_elided = fontMetrics ().elidedText ( _text, _elide_mode, width () );
+  const QMargins mgs = contentsMargins ();
+  _text_elided = fontMetrics ().elidedText (
+      _text, _elide_mode, qMax ( width () - mgs.left () - mgs.right (), 0 ) );
 }
 
 void
@@ -69,14 +91,20 @@ Label_Elide::resizeEvent ( QResizeEvent * event_n )
 {
   QWidget::resizeEvent ( event_n );
   update_text_elided ();
+  update ();
 }
 
 void
 Label_Elide::paintEvent ( QPaintEvent * event_n )
 {
   QWidget::paintEvent ( event_n );
-  QPainter painter ( this );
-  painter.drawText ( contentsRect (), _alignment, _text_elided );
+  {
+    QPainter painter ( this );
+    painter.setRenderHints ( QPainter::Antialiasing |
+                             QPainter::TextAntialiasing |
+                             QPainter::SmoothPixmapTransform );
+    painter.drawText ( contentsRect (), _alignment, _text_elided );
+  }
 }
 
 } // namespace Wdg
