@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_pad_focus_info_hpp__
-#define __INC_pad_focus_info_hpp__
+#pragma once
 
 namespace Wdg
 {
@@ -11,10 +10,13 @@ namespace Wdg
 ///
 class Pad_Focus_Info
 {
-  // Public methods
   public:
+  // -- Construction
+
   Pad_Focus_Info ();
 
+  ~Pad_Focus_Info ();
+
   void
   clear ();
 
@@ -27,5 +29,3 @@ class Pad_Focus_Info
 };
 
 } // namespace Wdg
-
-#endif
