@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_pass_events_hpp__
-#define __INC_pass_events_hpp__
+#pragma once
 
 #include <QEvent>
 #include <QFocusEvent>
@@ -15,13 +14,16 @@ namespace Wdg
 ///
 class Pass_Event : public QEvent
 {
-  // Public methods
   public:
+  // -- Construction
+
   Pass_Event ( QEvent::Type type_n,
                unsigned int group_idx_n = 0,
                unsigned int column_idx_n = 0,
                unsigned int row_idx_n = 0 );
 
+  ~Pass_Event ();
+
   unsigned int group_idx;
   unsigned int column_idx;
   unsigned int row_idx;
@@ -29,32 +31,36 @@ class Pass_Event : public QEvent
 
 /// @brief Pass_Event_Focus
 ///
-class Pass_Event_Focus : public ::Wdg::Pass_Event
+class Pass_Event_Focus : public Wdg::Pass_Event
 {
-  // Public methods
   public:
+  // -- Construction
+
   Pass_Event_Focus ( const QFocusEvent & event_n,
                      unsigned int group_idx_n = 0,
                      unsigned int column_idx_n = 0,
                      unsigned int row_idx_n = 0 );
 
+  ~Pass_Event_Focus ();
+
   QFocusEvent ev_focus;
 };
 
 /// @brief Pass_Event_Key
 ///
-class Pass_Event_Key : public ::Wdg::Pass_Event
+class Pass_Event_Key : public Wdg::Pass_Event
 {
-  // Public methods
   public:
+  // -- Construction
+
   Pass_Event_Key ( const QKeyEvent & event_n,
                    unsigned int group_idx_n = 0,
                    unsigned int column_idx_n = 0,
                    unsigned int row_idx_n = 0 );
 
+  ~Pass_Event_Key ();
+
   QKeyEvent ev_key;
 };
 
 } // namespace Wdg
-
-#endif
