@@ -17,12 +17,14 @@ Scroll_Area_Horizontal::Scroll_Area_Horizontal ( QWidget * parent_n )
   setWidgetResizable ( true );
 }
 
+Scroll_Area_Horizontal::~Scroll_Area_Horizontal () = default;
+
 QSize
 Scroll_Area_Horizontal::minimumSizeHint () const
 {
-  QSize res = ( QScrollArea::minimumSizeHint () );
+  QSize res = QScrollArea::minimumSizeHint ();
 
-  if ( widget () != 0 ) {
+  if ( widget () != nullptr ) {
     res.setHeight ( 0 );
     {
       const QSize wmsh ( widget ()->minimumSizeHint () );
@@ -30,8 +32,8 @@ Scroll_Area_Horizontal::minimumSizeHint () const
         res.rheight () += wmsh.height ();
       }
     }
-    if ( horizontalScrollBar () != 0 ) {
-      QSize sb_msh ( horizontalScrollBar ()->minimumSizeHint () );
+    if ( horizontalScrollBar () != nullptr ) {
+      QSize sb_msh = horizontalScrollBar ()->minimumSizeHint ();
       if ( sb_msh.height () <= 0 ) {
         sb_msh = horizontalScrollBar ()->sizeHint ();
       }
@@ -40,7 +42,7 @@ Scroll_Area_Horizontal::minimumSizeHint () const
       }
     }
     {
-      const QMargins mgs ( contentsMargins () );
+      const QMargins mgs = contentsMargins ();
       res.rheight () += ( mgs.top () + mgs.bottom () );
     }
   }
@@ -51,13 +53,13 @@ Scroll_Area_Horizontal::minimumSizeHint () const
 void
 Scroll_Area_Horizontal::set_widget ( QWidget * wdg_n )
 {
-  if ( widget () != 0 ) {
+  if ( widget () != nullptr ) {
     widget ()->removeEventFilter ( this );
   }
 
   setWidget ( wdg_n );
 
-  if ( widget () != 0 ) {
+  if ( widget () != nullptr ) {
     widget ()->installEventFilter ( this );
   }
 
@@ -67,7 +69,7 @@ Scroll_Area_Horizontal::set_widget ( QWidget * wdg_n )
 QWidget *
 Scroll_Area_Horizontal::take_widget ()
 {
-  if ( widget () != 0 ) {
+  if ( widget () != nullptr ) {
     widget ()->removeEventFilter ( this );
   }
   return takeWidget ();
@@ -77,7 +79,7 @@ bool
 Scroll_Area_Horizontal::eventFilter ( QObject * watched_n, QEvent * event_n )
 {
   if ( watched_n == widget () ) {
-    //::std::cout << "Event type: " << event_n->type() << "\n";
+    // std::cout << "Event type: " << event_n->type() << "\n";
     if ( event_n->type () == QEvent::LayoutRequest ) {
       updateGeometry ();
     }
