@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_scroll_area_horizontal_hpp__
-#define __INC_scroll_area_horizontal_hpp__
+#pragma once
 
 #include <QScrollArea>
 
@@ -13,12 +12,19 @@ namespace Wdg
 ///
 class Scroll_Area_Horizontal : public QScrollArea
 {
-  // Public methods
   public:
-  Scroll_Area_Horizontal ( QWidget * parent_n = 0 );
+  // -- Construction
+
+  Scroll_Area_Horizontal ( QWidget * parent_n = nullptr );
+
+  ~Scroll_Area_Horizontal ();
+
+  // -- Size hint
 
   QSize
-  minimumSizeHint () const;
+  minimumSizeHint () const override;
+
+  // -- Widget
 
   void
   set_widget ( QWidget * wdg_n );
@@ -26,12 +32,11 @@ class Scroll_Area_Horizontal : public QScrollArea
   QWidget *
   take_widget ();
 
-  // Protected methods
   protected:
+  // -- Protected methods
+
   bool
-  eventFilter ( QObject * watched_n, QEvent * event_n );
+  eventFilter ( QObject * watched_n, QEvent * event_n ) override;
 };
 
 } // namespace Wdg
-
-#endif
