@@ -1,8 +1,7 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_text_browser_hpp__
-#define __INC_text_browser_hpp__
+#pragma once
 
 #include <QScrollBar>
 #include <QString>
@@ -12,11 +11,18 @@
 namespace Wdg
 {
 
+/// @brief Text_Browser
+///
 class Text_Browser : public QTextBrowser
 {
-  // Public methods
   public:
-  Text_Browser ( QWidget * parent = 0 );
+  // -- Construction
+
+  Text_Browser ( QWidget * parent = nullptr );
+
+  ~Text_Browser ();
+
+  // -- Content
 
   void
   setPlainText ( const QString & txt_n );
@@ -24,20 +30,21 @@ class Text_Browser : public QTextBrowser
   void
   setHtml ( const QString & txt_n );
 
+  // -- Size hint
+
   QSize
   sizeHint () const;
 
-  // Protected methods
   protected:
+  // -- Protected methods
+
   void
   update_size_hint ();
 
-  // Private attributes
   private:
-  int _hint_width;
-  int _hint_height;
+  // -- Attributes
+  int _hint_width = 0;
+  int _hint_height = 0;
 };
 
 } // namespace Wdg
-
-#endif
