@@ -1,69 +1,71 @@
 /// QasTools: Desktop toolset for the Linux sound system ALSA.
 /// \copyright See COPYING file.
 
-#ifndef __INC_tree_view_kv_hpp__
-#define __INC_tree_view_kv_hpp__
+#pragma once
 
 #include <QTreeView>
 
 namespace Wdg
 {
 
-///
 /// @brief Tree_View_KV
 ///
 class Tree_View_KV : public QTreeView
 {
   Q_OBJECT
 
-  // Public methods
   public:
-  Tree_View_KV ( QWidget * parent = 0 );
+  // -- Construction
+
+  Tree_View_KV ( QWidget * parent = nullptr );
+
+  ~Tree_View_KV ();
+
+  // -- Model
 
   void
-  setModel ( QAbstractItemModel * model_n );
+  setModel ( QAbstractItemModel * model_n ) override;
 
-  // Activate current
+  // -- Activate current
 
   bool
-  activate_current () const;
+  activate_current () const
+  {
+    return _activate_current;
+  }
 
   void
   set_activate_current ( bool flag_n );
 
-  // Public slots
-  public slots:
+  // -- Public slots
 
+  Q_SLOT
   void
   set_expanded_recursive ( const QModelIndex & index_n,
                            int depth_n,
                            bool expanded_n );
 
+  Q_SLOT
   void
   expand_recursive ( const QModelIndex & index_n, int depth_n );
 
+  Q_SLOT
   void
   collapse_recursive ( const QModelIndex & index_n, int depth_n );
 
+  Q_SLOT
   void
   adjust_first_column_width ();
 
-  // Protected methods
   protected:
+  // -- Protected methods
+
   void
   currentChanged ( const QModelIndex & current, const QModelIndex & previous );
 
-  // Private attributes
   private:
-  bool _activate_current;
+  // -- Attributes
+  bool _activate_current = true;
 };
 
-inline bool
-Tree_View_KV::activate_current () const
-{
-  return _activate_current;
-}
-
 } // namespace Wdg
-
-#endif
